@@ -1,4 +1,4 @@
-PYXB_ROOT=${PYXB_ROOT:-/home/pab/pyxb/dev}
+PYXB_ROOT=${PYXB_ROOT:-/pyxb/dev}
 PYTHONPATH=${PYXB_ROOT}:${PYTHONPATH:+:${PYTHONPATH}}
 PATH="${PYXB_ROOT}/scripts:${PYXB_ROOT}/bin:${PATH}"
 export PYXB_ROOT PYTHONPATH PATH
