@@ -55,14 +55,18 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
 
     _ReservedSymbols = set([ 'validateBinding', 'toDOM', 'toxml', 'Factory', 'property' ])
 
-    def __setattr__ (self, name, value):
-        if name in self._ReservedSymbols:
-            raise pyxb.BindingError('Attempt to set reserved name %s in instance of %s' % (name, type(self)))
-        return super(_TypeBinding_mixin, self).__setattr__(name, value)
+    if pyxb._CorruptionDetectionEnabled:
+        def __setattr__ (self, name, value):
+            if name in self._ReservedSymbols:
+                raise pyxb.BindingError('Attempt to set reserved name %s in instance of %s' % (name, type(self)))
+            return super(_TypeBinding_mixin, self).__setattr__(name, value)
 
     # @todo: We don't actually use this anymore; get rid of it, just leaving a
     # comment describing each keyword.
-    _PyXBFactoryKeywords = ( '_dom_node', '_fallback_namespace', '_apply_whitespace_facet', '_validate_constraints', '_require_value', '_nil', '_element' )
+    _PyXBFactoryKeywords = ( '_dom_node', '_fallback_namespace', '_from_xml',
+                             '_apply_whitespace_facet', '_validate_constraints',
+                             '_require_value', '_nil', '_element',
+                             '_convert_string_values' )
     """Keywords that are interpreted by __new__ or __init__ in one or more
     classes in the PyXB type hierarchy.  All these keywords must be removed
     before invoking base Python __init__ or __new__."""
@@ -192,6 +196,13 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
         @keyword _dom_node: If provided, the value must be a DOM node, the
         content of which will be used to set the value of the instance.
 
+        @keyword _from_xml: If C{True}, the input must be either a DOM node or
+        a unicode string comprising a lexical representation of a value.  This
+        is a further control on C{_apply_whitespace_facet} and arises from
+        cases where the lexical and value representations cannot be
+        distinguished by type.  The default value is C{True} iff C{_dom_node}
+        is not C{None}.
+
         @keyword _apply_whitespace_facet: If C{True} and this is a
         simpleTypeDefinition with a whiteSpace facet, the first argument will
         be normalized in accordance with that facet prior to invoking the
@@ -210,6 +221,7 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
         # Invoke _PreFactory_vx for the superseding class, which is where
         # customizations will be found.
         dom_node = kw.get('_dom_node')
+        kw.setdefault('_from_xml', dom_node is not None)
         used_cls = cls._SupersedingClass()
         state = used_cls._PreFactory_vx(args, kw)
         rv = cls._DynamicCreate(*args, **kw)
@@ -223,8 +235,20 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
             return False
         return self._element().substitutesFor(element)
 
+    @classmethod
+    def _IsUrType (cls):
+        """Return C{True} iff this is the ur-type.
+
+        The only ur-type is {http://www.w3.org/2001/XMLSchema}anyType.  The
+        implementation of this method is overridden for
+        L{pyxb.binding.datatypes.anyType}."""
+        return False
+
     @classmethod
     def _RequireXSIType (cls, value_type):
+        if cls._IsUrType():
+            # Require xsi:type if value refines xs:anyType
+            return value_type != cls
         return cls._Abstract and value_type != cls._SupersedingClass()
 
     @classmethod
@@ -241,7 +265,7 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
         type-compatible with C{xs:byte}, it is outside the value space, and
         compatibility will fail.
 
-        @keyword convert_string_values: If C{True} (default) and the incoming value is
+        @keyword _convert_string_values: If C{True} (default) and the incoming value is
         a string, an attempt will be made to form a compatible value by using
         the string as a constructor argument to the this class.  This flag is
         set to C{False} when testing automaton transitions.
@@ -249,7 +273,7 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
         @raise pyxb.BadTypeValueError: if the value is not both
         type-consistent and value-consistent with the element's type.
         """
-        convert_string_values = kw.get('convert_string_values', True)
+        convert_string_values = kw.get('_convert_string_values', True)
         # None is always None
         if value is None:
             return None
@@ -293,7 +317,10 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
         # Any type is compatible with the corresponding ur-type
         if (pyxb.binding.datatypes.anySimpleType == cls) and issubclass(value_type, simpleTypeDefinition):
             return value
-        if (pyxb.binding.datatypes.anyType == cls) and issubclass(value_type, complexTypeDefinition):
+        if pyxb.binding.datatypes.anyType == cls:
+            if not isinstance(value, _TypeBinding_mixin):
+                print 'NOTE: Created %s instance from value of type %s' % (cls._ExpandedName, type(value))
+                value = cls(value)
             return value
 
         # Is this the wrapper class that indicates we should create a binding
@@ -395,6 +422,10 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
             self._validateBinding_vx()
         return True
 
+    def _postDOMValidate (self):
+        self.validateBinding()
+        return self
+
     @classmethod
     def _Name (cls):
         if cls._ExpandedName is not None:
@@ -477,6 +508,8 @@ class _DynamicCreate_mixin (pyxb.cscRoot):
         try:
             return ctor(*args, **kw)
         except TypeError, e:
+            #import traceback
+            #traceback.print_exc()
             raise pyxb.BadTypeValueError(e)
 
 class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
@@ -520,8 +553,11 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
     # Determine the name of the class-private facet map.  For the base class
     # this should produce the same attribute name as Python's privatization
     # scheme.
+    __FacetMapAttributeNameMap = { }
     @classmethod
     def __FacetMapAttributeName (cls):
+        """ """
+        '''
         if cls == simpleTypeDefinition:
             return '_%s__FacetMap' % (cls.__name__.strip('_'),)
 
@@ -534,8 +570,26 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         except Exception, e:
             pass
         nm = '_' + utility.MakeIdentifier('%s_%s_FacetMap' % (ns_uri, cls.__name__.strip('_')))
+        '''
+        nm = cls.__FacetMapAttributeNameMap.get(cls)
+        if nm is None:
+            nm = cls.__name__
+            if nm.endswith('_'):
+                nm += '1'
+            if cls == simpleTypeDefinition:
+                nm = '_%s__FacetMap' % (nm,)
+            else:
+                # It is not uncommon for a class in one namespace to extend a class of
+                # the same name in a different namespace, so encode the namespace URI
+                # in the attribute name (if it is part of a namespace).
+                ns_uri = ''
+                try:
+                    ns_uri = cls._ExpandedName.namespaceURI()
+                except Exception, e:
+                    pass
+                nm = '_' + utility.MakeIdentifier('%s_%s_FacetMap' % (ns_uri, nm))
+            cls.__FacetMapAttributeNameMap[cls] = nm
         return nm
-        
 
     @classmethod
     def _FacetMap (cls):
@@ -566,7 +620,7 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         except AttributeError:
             pass
         if fm is not None:
-            raise pyxb.LogicError('%s facet map initialized multiple times: %s' % (cls.__name__,cls.__FacetMapAttributeName()))
+            raise pyxb.LogicError('%s facet map initialized multiple times: %s' % (cls.__name__, cls.__FacetMapAttributeName()))
 
         # Search up the type hierarchy to find the nearest ancestor that has a
         # facet map.  This gets a bit tricky: if we hit the ceiling early
@@ -623,18 +677,20 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         string to a list.  Binding-specific applications are performed in the
         overloaded L{_ConvertArguments_vx} method."""
         dom_node = kw.pop('_dom_node', None)
+        from_xml = kw.get('_from_xml', dom_node is not None)
         if dom_node is not None:
             text_content = domutils.ExtractTextContent(dom_node)
             if text_content is not None:
                 args = (domutils.ExtractTextContent(dom_node),) + args
                 kw['_apply_whitespace_facet'] = True
-        apply_whitespace_facet = kw.pop('_apply_whitespace_facet', True)
-        if (0 < len(args)) and isinstance(args[0], types.StringTypes):
+        apply_whitespace_facet = kw.pop('_apply_whitespace_facet', from_xml)
+        if (0 < len(args)) and isinstance(args[0], types.StringTypes) and apply_whitespace_facet:
             cf_whitespace = getattr(cls, '_CF_whiteSpace', None)
             if cf_whitespace is not None:
                 #print 'Apply whitespace %s to "%s"' % (cf_whitespace, args[0])
                 norm_str = unicode(cf_whitespace.normalizeString(args[0]))
                 args = (norm_str,) + args[1:]
+        kw['_from_xml'] = from_xml
         return cls._ConvertArguments_vx(args, kw)
 
     # Must override new, because new gets invoked before init, and usually
@@ -656,6 +712,7 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         kw.pop('_nil', None)
         # ConvertArguments will remove _element and _apply_whitespace_facet
         args = cls._ConvertArguments(args, kw)
+        kw.pop('_from_xml', None)
         assert issubclass(cls, _TypeBinding_mixin)
         try:
             rv = super(simpleTypeDefinition, cls).__new__(cls, *args, **kw)
@@ -778,6 +835,10 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         super_fn = getattr(super(simpleTypeDefinition, cls), '_XsdConstraintsPreCheck_vb', lambda *a,**kw: value)
         return super_fn(value)
 
+    # Cache of pre-computed sequences of class facets in the order required
+    # for constraint validation
+    __ClassFacetSequence = { }
+
     @classmethod
     def XsdConstraintsOK (cls, value):
         """Validate the given value against the constraints on this class.
@@ -787,25 +848,35 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
 
         value = cls._XsdConstraintsPreCheck_vb(value)
 
-        facet_values = None
-
-        # Constraints for simple type definitions are inherited.  Check them
-        # from least derived to most derived.
-        classes = [ _x for _x in cls.mro() if issubclass(_x, simpleTypeDefinition) ]
-        classes.reverse()
-        for clazz in classes:
-            # When setting up the datatypes, if we attempt to validate
-            # something before the facets have been initialized (e.g., a
-            # nonNegativeInteger used as a length facet for the parent
-            # integer datatype), just ignore that.
-            try:
-                facet_values = clazz._FacetMap().values()
-            except AttributeError, e:
-                facet_values = []
-            for f in facet_values:
-                if not f.validateConstraint(value):
-                    raise pyxb.BadTypeValueError('%s violation for %s in %s' % (f.Name(), value, cls.__name__))
-                #print '%s ok for %s' % (f, value)
+        facet_values = cls.__ClassFacetSequence.get(cls)
+        if facet_values is None:
+            # Constraints for simple type definitions are inherited.  Check them
+            # from least derived to most derived.
+            classes = [ _x for _x in cls.mro() if issubclass(_x, simpleTypeDefinition) ]
+            classes.reverse()
+            cache_result = True
+            facet_values = []
+            for clazz in classes:
+                # When setting up the datatypes, if we attempt to validate
+                # something before the facets have been initialized (e.g., a
+                # nonNegativeInteger used as a length facet for the parent
+                # integer datatype), just ignore that for now.  Don't cache
+                # the value, though, since a subsequent check after
+                # initialization should succceed.
+                try:
+                    clazz_facets = clazz._FacetMap().values()
+                except AttributeError, e:
+                    cache_result = False
+                    clazz_facets = []
+                for v in clazz_facets:
+                    if not (v in facet_values):
+                        facet_values.append(v)
+            if cache_result:
+                cls.__ClassFacetSequence[cls] = facet_values
+        for f in facet_values:
+            if not f.validateConstraint(value):
+                raise pyxb.BadTypeValueError('%s violation for %s in %s' % (f.Name(), value, cls.__name__))
+            #print '%s ok for %s' % (f, value)
         return value
 
     def xsdConstraintsOK (self):
@@ -1127,7 +1198,7 @@ class STD_list (simpleTypeDefinition, types.ListType):
     def append (self, x):
         super(STD_list, self).append(self._ValidatedItem(x))
 
-    def extend (self, x):
+    def extend (self, x, _from_xml=False):
         super(STD_list, self).extend(self.__convertMany(x))
 
     def count (self, x):
@@ -1193,6 +1264,8 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         return self.__substitutionGroup
     def _setSubstitutionGroup (self, substitution_group):
         self.__substitutionGroup = substitution_group
+        if substitution_group is not None:
+            self.substitutesFor = self._real_substitutesFor
         return self
     __substitutionGroup = None
 
@@ -1204,7 +1277,7 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
             return None
         return self.substitutionGroup().findSubstituendUse(ctd_class)
 
-    def substitutesFor (self, other):
+    def _real_substitutesFor (self, other):
         """Determine whether an instance of this element can substitute for the other element.
         
         See U{Substitution Group OK<http://www.w3.org/TR/xmlschema-1/#cos-equiv-derived-ok-rec>)}.
@@ -1212,6 +1285,8 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         @todo: Do something about blocking constraints.  This ignores them, as
         does everything leading to this point.
         """
+        if self.substitutionGroup() is None:
+            return False
         if other is None:
             return False
         assert isinstance(other, element)
@@ -1225,10 +1300,12 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         # Do both these refer to the same (top-level) element?
         if self.name().elementBinding() == other:
             return True
-        if self.substitutionGroup() is None:
-            return False
         return (self.substitutionGroup() == other) or self.substitutionGroup().substitutesFor(other)
 
+    def substitutesFor (self, other):
+        """Stub replaced by _real_substitutesFor when element supports substitution groups."""
+        return False
+
     def memberElement (self, name):
         """Return a reference to the element instance used for the given name
         within this element.
@@ -1256,6 +1333,8 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         for initialization.  In that case, the L{createFromDOM} method is
         invoked instead of the type definition Factory method.
 
+        @note: Other keywords are passed to L{_TypeBinding_mixin.Factory}.
+
         @raise pyxb.AbstractElementError: This element is abstract and no DOM
         node was provided.
         """
@@ -1280,7 +1359,7 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         # None is always None
         if value is None:
             return None
-        is_plural = kw.get('is_plural', False)
+        is_plural = kw.pop('is_plural', False)
         #print 'validating %s against %s, isPlural %s' % (type(value), self.typeDefinition(), is_plural)
         if is_plural:
             try:
@@ -1300,7 +1379,7 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         expanded_name = pyxb.namespace.ExpandedName(node, fallback_namespace=_fallback_namespace)
         elt = expanded_name.elementBinding()
         if elt is None:
-            raise pyxb.UnrecognizedElementError('No element binding available for %s' % (expanded_name,))
+            raise pyxb.UnrecognizedElementError(dom_node=node, element_name=expanded_name)
         assert isinstance(elt, pyxb.binding.basis.element)
         # Pass on the namespace to use when resolving unqualified qnames as in
         # xsi:type
@@ -1442,9 +1521,7 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         rv = type_class.Factory(_dom_node=node, _fallback_namespace=fallback_namespace, **kw)
         assert rv._element() == element_binding
         rv._setNamespaceContext(ns_ctx)
-        if pyxb._ParsingRequiresValid:
-            rv.validateBinding()
-        return rv
+        return rv._postDOMValidate()
 
     def __str__ (self):
         return 'Element %s' % (self.name(),)
@@ -1555,16 +1632,20 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         Arguments are used as transition values along the content model.
         Keywords are passed to the constructor of any simple content, or used
         to initialize attribute and element values whose L{id
-        <content.ElementUse.id>} matches the keyword.
+        <content.ElementUse.id>} (not L{name <content.ElementUse.name>})
+        matches the keyword.
 
         @keyword _dom_node: The node to use as the source of binding content.
         @type _dom_node: C{xml.dom.Element}
 
+        @keyword _from_xml: See L{_TypeBinding_mixin.Factory}
+
         """
 
         fallback_namespace = kw.pop('_fallback_namespace', None)
         is_nil = False
         dom_node = kw.pop('_dom_node', None)
+        from_xml = kw.pop('_from_xml', dom_node is not None)
         if dom_node is not None:
             if isinstance(dom_node, pyxb.utils.utility.Locatable_mixin):
                 self._setLocation(dom_node.location)
@@ -1587,22 +1668,26 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         if dom_node is not None:
             attribute_settings.update(self.__AttributesFromDOM(dom_node))
         for fu in self._AttributeMap.values():
-            iv = kw.get(fu.id())
+            iv = kw.pop(fu.id(), None)
             if iv is not None:
                 attribute_settings[fu.name()] = iv
         for (attr_en, value) in attribute_settings.items():
             au = self._setAttribute(attr_en, value)
         for fu in self._ElementMap.values():
-            iv = kw.get(fu.id())
+            iv = kw.pop(fu.id(), None)
             if iv is not None:
                 fu.set(self, iv)
+        if kw and kw.pop('_strict_keywords', True):
+            [ kw.pop(_fkw, None) for _fkw in self._PyXBFactoryKeywords ]
+            if kw:
+                raise pyxb.ExtraContentError(kw)
         if dom_node is not None:
             if self._CT_SIMPLE == self._ContentTypeTag:
                 self.__initializeSimpleContent(args, dom_node)
             else:
                 self._setContentFromDOM(dom_node, fallback_namespace)
         elif 0 < len(args):
-            self.extend(args)
+            self.extend(args, _from_xml=from_xml)
         else:
             if self._CT_SIMPLE == self._ContentTypeTag:
                 self.__initializeSimpleContent(args, dom_node)
@@ -1623,7 +1708,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
     _ReservedSymbols = _TypeBinding_mixin._ReservedSymbols.union(set([ 'wildcardElements', 'wildcardAttributeMap',
                              'xsdConstraintsOK', 'content', 'append', 'extend', 'value', 'reset' ]))
 
-    # None, or a reference to a ContentModel instance that defines how to
+    # None, or a reference to a ParticleModel instance that defines how to
     # reduce a DOM node list to the body of this element.
     _ContentModel = None
 
@@ -1644,7 +1729,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         @param tag: The L{ExpandedName} of an element in the class."""
         rv = cls._ElementMap.get(tag)
         if (rv is None) and raise_if_fail:
-            raise pyxb.NotAnElementError('Unable to locate element %s in type %s' % (tag, cls._ExpandedName))
+            raise pyxb.NotAnElementError(tag, cls)
         return rv
 
     def __childrenForDOM (self):
@@ -1681,7 +1766,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         model, C{None} is returned.
 
         The base class implementation uses the
-        L{content.ContentModel.validate} method.  Subclasses may desire to
+        L{content.ParticleModel.validate} method.  Subclasses may desire to
         override this in cases where the desired order is not maintained by
         model interpretation (for example, when an "all" model is used and the
         original element order is desired).  See L{__childrenForDOM} as an
@@ -1731,13 +1816,12 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
                 rv[eu] = [ converter(value)]
         wce = self.wildcardElements()
         if (wce is not None) and (0 < len(wce)):
-            rv[None] = wce
+            rv[None] = wce[:]
         return rv
 
     def _validateAttributes (self):
         for au in self._AttributeMap.values():
             au.validate(self)
-        
 
     def _validateBinding_vx (self):
         if self._isNil():
@@ -1856,7 +1940,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         else:
             self.__setContent(None)
 
-    __dfaStack = None
+    __modelState = None
     def reset (self):
         """Reset the instance.
 
@@ -1871,7 +1955,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         for eu in self._ElementMap.values():
             eu.reset(self)
         if self._ContentModel is not None:
-            self.__dfaStack = self._ContentModel.initialDFAStack()
+            self.__modelState = self._ContentModel.newState()
         return self
 
     @classmethod
@@ -1913,7 +1997,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
             element_binding = element_use.elementBinding()
         return (element_binding, element_use)
         
-    def append (self, value, element_use=None, maybe_element=True, _fallback_namespace=None, require_validation=True):
+    def append (self, value, element_use=None, maybe_element=True, _fallback_namespace=None, require_validation=True, _from_xml=False):
         """Add the value to the instance.
 
         The value should be a DOM node or other value that is or can be
@@ -1934,6 +2018,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
             assert element_binding is not None
         # Convert the value if it's XML and we recognize it.
         if isinstance(value, xml.dom.Node):
+            _from_xml = True
             assert maybe_element
             assert element_binding is None
             node = value
@@ -1970,7 +2055,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
                                     value = mr.module().CreateFromDOM(node)
                                     break
                                 except pyxb.PyXBException, e:
-                                    print 'Ignoring creating binding for wildcard %s: %s' % (expanded_name, e)
+                                    print 'Ignoring error when creating binding for wildcard %s: %s' % (expanded_name, e)
                                 except AttributeError, e:
                                     # The module holding XMLSchema bindnigs does not
                                     # have a CreateFromDOM method, and shouldn't since
@@ -1985,24 +2070,26 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
                 return self
         if self._isNil() and not self._IsSimpleTypeContent():
             raise pyxb.ExtraContentError('%s: Content %s present in element with xsi:nil' % (type(self), value))
-        if maybe_element and (self.__dfaStack is not None):
+        if maybe_element and (self.__modelState is not None):
             # Allows element content.
             if not require_validation:
                 if element_use is not None:
                     element_use.setOrAppend(self, value)
                     return self
-                raise pyxb.binding.StructuralBadDocumentError('Validation is required when no element_use can be found')
+                raise pyxb.StructuralBadDocumentError('Validation is required when no element_use can be found')
                 if self.wildcardElements() is not None:
                     self._appendWildcardElement(value)
                     return self
             else:
-                if self.__dfaStack.step(self, value, element_use):
+                #print 'SSStep %s %s' % (value, element_use)
+                ( consumed, underflow_exc ) = self.__modelState.step(self, value, element_use)
+                if consumed:
                     return self
         # If what we have is element content, we can't accept it, either
         # because the type doesn't accept element content or because it does
         # and what we got didn't match the content model.
         if (element_binding is not None) or isinstance(value, xml.dom.Node):
-            raise pyxb.ExtraContentError('%s: Extra content starting with %s' % (self._ExpandedName, value,))
+            raise pyxb.ExtraContentError('%s: Extra content %s starting with %s' % (self._ExpandedName, element_binding, value,))
 
         # We have something that doesn't seem to be an element.  Are we
         # expecting simple content?
@@ -2011,7 +2098,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
                 raise pyxb.ExtraContentError('Extra content starting with %s (already have %s)' % (value, self.__content))
             if not self._isNil():
                 if not isinstance(value, self._TypeDefinition):
-                    value = self._TypeDefinition.Factory(value)
+                    value = self._TypeDefinition.Factory(value, _from_xml=_from_xml)
                 self.__setContent(value)
                 if require_validation:
                     # NB: This only validates the value, not any associated
@@ -2032,12 +2119,12 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
     def _appendWildcardElement (self, value):
         wcl = self.wildcardElements()
         if wcl is None:
-            raise pyxb.UnrecognizedContentError(value)
+            raise pyxb.UnrecognizedContentError(value, container=self)
         wcl.append(value)
         
-    def extend (self, value_list, _fallback_namespace=None):
+    def extend (self, value_list, _fallback_namespace=None, _from_xml=False):
         """Invoke L{append} for each value in the list, in turn."""
-        [ self.append(_v, _fallback_namespace=_fallback_namespace) for _v in value_list ]
+        [ self.append(_v, _fallback_namespace=_fallback_namespace, _from_xml=_from_xml) for _v in value_list ]
         return self
 
     def __setContent (self, value):
@@ -2056,13 +2143,17 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
     def _IsMixed (cls):
         return (cls._CT_MIXED == cls._ContentTypeTag)
     
+    def _postDOMValidate (self):
+        if self._PerformValidation() and (not self._isNil()) and (self.__modelState is not None):
+            self.__modelState.verifyComplete()
+            self._validateAttributes()
+        return self
+
     def _setContentFromDOM (self, node, _fallback_namespace):
         """Initialize the content of this element from the content of the DOM node."""
 
         self.extend(node.childNodes[:], _fallback_namespace)
-        if self._PerformValidation() and (not self._isNil()) and (self.__dfaStack is not None) and (not self.__dfaStack.isTerminal()):
-            raise pyxb.MissingContentError()
-        return self
+        return self._postDOMValidate()
 
     def _setDOMFromAttributes (self, dom_support, element):
         """Add any appropriate attributes from this instance into the DOM element."""
