@@ -12,7 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-"""Classes supporting U{XMLSchema Part 2: Datatypes<http://www/Documentation/W3C/www.w3.org/TR/xmlschema-2/index.html>}.
+"""Classes supporting U{XMLSchema Part 2: Datatypes<http://www.w3.org/TR/xmlschema-2/>}.
 
 Each L{simple type definition<pyxb.xmlschema.structures.SimpleTypeDefinition>} component
 instance is paired with at most one L{basis.simpleTypeDefinition}
@@ -49,6 +49,8 @@ import pyxb.utils.domutils as domutils
 import pyxb.utils.utility as utility
 import basis
 import re
+import binascii
+import base64
 
 _PrimitiveDatatypes = []
 _DerivedDatatypes = []
@@ -58,7 +60,7 @@ _ListDatatypes = []
 # primitive type.  Presumably, only enumeration and pattern facets
 # will be applied.
 class anySimpleType (basis.simpleTypeDefinition, unicode):
-    """See U{http://www.w3.org/TR/xmlschema-2/#dt-anySimpleType}"""
+    """XMLSchema datatype U{anySimpleType<http://www.w3.org/TR/xmlschema-2/#dt-anySimpleType>}."""
     _XsdBaseType = None
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('anySimpleType')
 
@@ -69,9 +71,7 @@ class anySimpleType (basis.simpleTypeDefinition, unicode):
 # must be absent (not atomic).
     
 class string (basis.simpleTypeDefinition, unicode):
-    """string.
-    
-    U{http://www.w3.org/TR/xmlschema-2/#string}"""
+    """XMLSchema datatype U{string<http://www.w3.org/TR/xmlschema-2/#string>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('string')
 
@@ -89,9 +89,7 @@ _PrimitiveDatatypes.append(string)
 # It is illegal to subclass the bool type in Python, so we subclass
 # int instead.
 class boolean (basis.simpleTypeDefinition, types.IntType):
-    """boolean.
-
-    U{http://www.w3.org/TR/xmlschema-2/#boolean}"""
+    """XMLSchema datatype U{boolean<http://www.w3.org/TR/xmlschema-2/#boolean>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('boolean')
     
@@ -123,9 +121,7 @@ class boolean (basis.simpleTypeDefinition, types.IntType):
 _PrimitiveDatatypes.append(boolean)
 
 class decimal (basis.simpleTypeDefinition, types.FloatType):
-    """decimal.
-    
-    U{http://www.w3.org/TR/xmlschema-2/#decimal}
+    """XMLSchema datatype U{decimal<http://www.w3.org/TR/xmlschema-2/#decimal>}.
 
     @todo: The Python base type for this is wrong. Consider
     U{http://code.google.com/p/mpmath/}.
@@ -141,9 +137,7 @@ class decimal (basis.simpleTypeDefinition, types.FloatType):
 _PrimitiveDatatypes.append(decimal)
 
 class float (basis.simpleTypeDefinition, types.FloatType):
-    """float.
-
-    U{http://www.w3.org/TR/xmlschema-2/#float}"""
+    """XMLSchema datatype U{float<http://www.w3.org/TR/xmlschema-2/#float>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('float')
 
@@ -154,9 +148,7 @@ class float (basis.simpleTypeDefinition, types.FloatType):
 _PrimitiveDatatypes.append(float)
 
 class double (basis.simpleTypeDefinition, types.FloatType):
-    """double.
-
-    U{http://www.w3.org/TR/xmlschema-2/#double}"""
+    """XMLSchema datatype U{double<http://www.w3.org/TR/xmlschema-2/#double>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('double')
 
@@ -170,7 +162,7 @@ import time as python_time
 import datetime
 
 class duration (basis.simpleTypeDefinition, datetime.timedelta):
-    """U{http://www.w3.org/TR/xmlschema-2/#duration}
+    """XMLSchema datatype U{duration<http://www.w3.org/TR/xmlschema-2/#duration>}.
 
     This class uses the Python C{datetime.timedelta} class as its
     underlying representation.  This works fine as long as no months
@@ -400,7 +392,7 @@ class _PyXBDateTimeZone_base (_PyXBDateTime_base):
         return getattr(super(_PyXBDateTimeZone_base, cls), '_SetKeysFromPython_csc', lambda *a,**kw: None)(python_value, kw, fields)
 
 class dateTime (_PyXBDateTimeZone_base, datetime.datetime):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#dateTime}
+    """XMLSchema datatype U{dateTime<http://www.w3.org/TR/xmlschema-2/#dateTime>}.
 
     This class uses the Python C{datetime.datetime} class as its
     underlying representation.  Note that per the XMLSchema spec, all
@@ -493,7 +485,7 @@ class dateTime (_PyXBDateTimeZone_base, datetime.datetime):
 _PrimitiveDatatypes.append(dateTime)
 
 class time (_PyXBDateTimeZone_base, datetime.time):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#time}
+    """XMLSchema datatype U{time<http://www.w3.org/TR/xmlschema-2/#time>}.
 
     This class uses the Python C{datetime.time} class as its
     underlying representation.  Note that per the XMLSchema spec, all
@@ -597,7 +589,7 @@ class _PyXBDateOnly_base (_PyXBDateTime_base, datetime.date):
         return value.isoformat()[cls._ISOBegin:cls._ISOEnd]
 
 class date (_PyXBDateOnly_base):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#date}
+    """XMLSchema datatype U{date<http://www.w3.org/TR/xmlschema-2/#date>}.
 
     This class uses the Python C{datetime.date} class as its
     underlying representation.
@@ -610,7 +602,7 @@ class date (_PyXBDateOnly_base):
 _PrimitiveDatatypes.append(date)
 
 class gYearMonth (_PyXBDateOnly_base):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#gYearMonth}
+    """XMLSchema datatype U{gYearMonth<http://www.w3.org/TR/xmlschema-2/#gYearMonth>}.
 
     This class uses the Python C{datetime.date} class as its
     underlying representation.
@@ -623,7 +615,7 @@ class gYearMonth (_PyXBDateOnly_base):
 _PrimitiveDatatypes.append(gYearMonth)
 
 class gYear (_PyXBDateOnly_base):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#gYear}
+    """XMLSchema datatype U{gYear<http://www.w3.org/TR/xmlschema-2/#gYear>}.
 
     This class uses the Python C{datetime.date} class as its
     underlying representation.
@@ -635,7 +627,7 @@ class gYear (_PyXBDateOnly_base):
 _PrimitiveDatatypes.append(gYear)
 
 class gMonthDay (_PyXBDateOnly_base):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#gMonthDay}
+    """XMLSchema datatype U{gMonthDay<http://www.w3.org/TR/xmlschema-2/#gMonthDay>}.
 
     This class uses the Python C{datetime.date} class as its
     underlying representation.
@@ -647,7 +639,7 @@ class gMonthDay (_PyXBDateOnly_base):
 _PrimitiveDatatypes.append(gMonthDay)
 
 class gDay (_PyXBDateOnly_base):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#gDay}
+    """XMLSchema datatype U{gDay<http://www.w3.org/TR/xmlschema-2/#gDay>}.
 
     This class uses the Python C{datetime.date} class as its
     underlying representation.
@@ -659,7 +651,7 @@ class gDay (_PyXBDateOnly_base):
 _PrimitiveDatatypes.append(gDay)
 
 class gMonth (_PyXBDateOnly_base):
-    """U{http://www.w3.org/TR/xmlschema-2/index.html#gMonth}
+    """XMLSchema datatype U{gMonth<http://www.w3.org/TR/xmlschema-2/#gMonth>}.
 
     This class uses the Python C{datetime.date} class as its
     underlying representation.
@@ -671,95 +663,76 @@ class gMonth (_PyXBDateOnly_base):
     _ISOEnd = _PyXBDateOnly_base._ISO_endMonth
 _PrimitiveDatatypes.append(gMonth)
 
-class hexBinary (basis.simpleTypeDefinition, types.LongType):
+class hexBinary (basis.simpleTypeDefinition, types.StringType):
+    """XMLSchema datatype U{hexBinary<http://www.w3.org/TR/xmlschema-2/#hexBinary>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('hexBinary')
 
-    __length = None
-    def length (self):
-        """Return the length of the value, in octets."""
-        return self.__length
-
     @classmethod
-    def _ConvertString (cls, text):
-        """Convert a sequence of pairs of hex digits into a length (in
-        octets) and a binary value."""
-        assert isinstance(text, types.StringTypes)
-        value = 0L
-        length = 0
-        while (length < len(text)):
-            v = ord(text[length].lower())
-            if (ord('0') <= v) and (v <= ord('9')):
-                value = (value << 4) + v - ord('0')
-            elif (ord('a') <= v) and (v <= ord('f')):
-                value = (value << 4) + v - ord('a') + 10
-            else:
-                raise BadTypeValueError('Non-hexadecimal values in %s' % (cls.__class__.__name__,))
-            length += 1
-        if 0 == length:
-            raise BadTypeValueError('%s must be non-empty string' % (cls.__class__.__name__,))
-        if (length & 0x01):
-            raise BadTypeValueError('%s value ends mid-octet' % (cls.__class__.__name__,))
-        return (length >> 1, value)
-
-    @classmethod
-    def _ConvertValue (cls, value):
-        """Given an integral value, return a pair consisting of the
-        number of octets required to represent the value, and the
-        value."""
-        length = 0
-        if 0 == value:
-            length = 1
-        else:
-            mv = value
-            while (0 != mv):
-                length += 1
-                mv = mv >> 4
-            length = (length+1) >> 1
-        return (length, value)
-
-    def __new__ (cls, *args, **kw):
-        args = cls._ConvertArguments(args, kw)
-        value = args[0]
-        rem_args = args[1:]
-        if isinstance(value, types.StringTypes):
-            (length, binary_value) = cls._ConvertString(value)
-        else:
-            (length, binary_value) = cls._ConvertValue(value)
-        rv = super(hexBinary, cls).__new__(cls, binary_value, *rem_args, **kw)
-        rv.__length = length
-        return rv
+    def _ConvertArguments_vx (cls, args, kw):
+        if kw.get('_from_xml', False):
+            try:
+                args = (binascii.unhexlify(args[0]),) + args[1:]
+            except TypeError, e:
+                raise BadTypeValueError('%s is not a valid hexBinary string' % (cls.__class__.__name__,))
+        return args
 
     @classmethod
     def XsdLiteral (cls, value):
-        mv = value
-        length = value.length()
-        pieces = []
-        while (0 < length):
-            pieces.append('%2.2X' % (mv & 0xFF,))
-            mv = mv >> 8
-            length -= 1
-        pieces.reverse()
-        return ''.join(pieces)
+        return binascii.hexlify(value).upper()
 
     @classmethod
     def XsdValueLength (cls, value):
-        return value.length()
+        return len(value)
 
 _PrimitiveDatatypes.append(hexBinary)
 
-class base64Binary (basis.simpleTypeDefinition):
-    """@attention: Not implemented"""
+class base64Binary (basis.simpleTypeDefinition, types.StringType):
+    """XMLSchema datatype U{base64Binary<http://www.w3.org/TR/xmlschema-2/#base64Binary>}.
+
+    See also U{RFC2045<http://tools.ietf.org/html/rfc2045>} and U{RFC4648<http://tools.ietf.org/html/rfc4648>}.
+    """
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('base64Binary')
 
+    # base64 is too lenient: it accepts 'ZZZ=' as an encoding of 'e', while
+    # the required XML Schema production requires 'ZQ=='.  Define a regular
+    # expression per section 3.2.16.
+    _B04 = '[AQgw]'
+    _B04S = '(%s ?)' % (_B04,)
+    _B16 = '[AEIMQUYcgkosw048]'
+    _B16S = '(%s ?)' % (_B16,)
+    _B64 = '[ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/]'
+    _B64S = '(%s ?)' % (_B64,)
+
+    __Pattern = '^((' + _B64S + '{4})*((' + _B64S + '{3}' + _B64 + ')|(' + _B64S + '{2}' + _B16S + '=)|(' + _B64S + _B04S + '= ?=)))?$'
+    __Lexical_re = re.compile(__Pattern)
+
+    @classmethod
+    def _ConvertArguments_vx (cls, args, kw):
+        if kw.get('_from_xml', False):
+            xmls = args[0]
+            try:
+                args = (base64.standard_b64decode(xmls),) + args[1:]
+            except TypeError, e:
+                raise BadTypeValueError('%s is not a valid base64Binary string: %s' % (cls.__class__.__name__, str(e)))
+            # This is what it costs to try to be a validating processor.
+            if cls.__Lexical_re.match(xmls) is None:
+                raise BadTypeValueError('%s is not a valid base64Binary string: XML strict failed' % (cls.__class__.__name__,))
+        return args
+
+    @classmethod
+    def XsdLiteral (cls, value):
+        return base64.standard_b64encode(value)
+
     @classmethod
     def XsdValueLength (cls, value):
-        raise NotImplementedError('No length calculation for base64Binary')
+        return len(value)
 
 _PrimitiveDatatypes.append(base64Binary)
 
 class anyURI (basis.simpleTypeDefinition, unicode):
+    """XMLSchema datatype U{anyURI<http://www.w3.org/TR/xmlschema-2/#anyURI>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('anyURI')
 
@@ -774,6 +747,7 @@ class anyURI (basis.simpleTypeDefinition, unicode):
 _PrimitiveDatatypes.append(anyURI)
 
 class QName (basis.simpleTypeDefinition, unicode):
+    """XMLSchema datatype U{QName<http://www.w3.org/TR/xmlschema-2/#QName>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('QName')
 
@@ -825,6 +799,7 @@ class QName (basis.simpleTypeDefinition, unicode):
 _PrimitiveDatatypes.append(QName)
 
 class NOTATION (basis.simpleTypeDefinition):
+    """XMLSchema datatype U{NOTATION<http://www.w3.org/TR/xmlschema-2/#NOTATION>}."""
     _XsdBaseType = anySimpleType
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('NOTATION')
 
@@ -836,7 +811,7 @@ class NOTATION (basis.simpleTypeDefinition):
 _PrimitiveDatatypes.append(NOTATION)
 
 class normalizedString (string):
-    """See http:///www.w3.org/TR/xmlschema-2/index.html#normalizedString
+    """XMLSchema datatype U{normalizedString<http:///www.w3.org/TR/xmlschema-2/#normalizedString>}.
 
     Normalized strings can't have carriage returns, linefeeds, or
     tabs in them."""
@@ -906,7 +881,7 @@ _DerivedDatatypes.append(normalizedString)
 assert normalizedString.XsdSuperType() == string
 
 class token (normalizedString):
-    """See http:///www.w3.org/TR/xmlschema-2/index.html#token
+    """XMLSchema datatype U{token<http:///www.w3.org/TR/xmlschema-2/#token>}.
 
     Tokens cannot leading or trailing space characters; any
     carriage return, line feed, or tab characters; nor any occurrence
@@ -929,13 +904,15 @@ class token (normalizedString):
 _DerivedDatatypes.append(token)
 
 class language (token):
-    """See http:///www.w3.org/TR/xmlschema-2/index.html#language"""
+    """XMLSchema datatype U{language<http:///www.w3.org/TR/xmlschema-2/#language>}"""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('language')
     _ValidRE = re.compile('^[a-zA-Z]{1,8}(-[a-zA-Z0-9]{1,8})*$')
 _DerivedDatatypes.append(language)
 
 class NMTOKEN (token):
-    """See http://www.w3.org/TR/2000/WD-xml-2e-20000814.html#NT-Nmtoken
+    """XMLSchema datatype U{NMTOKEN<http:///www.w3.org/TR/xmlschema-2/#NMTOKEN>}.
+
+    See U{http://www.w3.org/TR/2000/WD-xml-2e-20000814.html#NT-Nmtoken}.
 
     NMTOKEN is an identifier that can start with any character that is
     legal in it."""
@@ -948,35 +925,43 @@ class NMTOKENS (basis.STD_list):
 _ListDatatypes.append(NMTOKENS)
 
 class Name (token):
-    """See http://www.w3.org/TR/2000/WD-xml-2e-20000814.html#NT-Name"""
+    """XMLSchema datatype U{Name<http:///www.w3.org/TR/xmlschema-2/#Name>}.
+
+    See U{http://www.w3.org/TR/2000/WD-xml-2e-20000814.html#NT-Name}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('Name')
     _ValidRE = re.compile('^[A-Za-z_:][-_.:A-Za-z0-9]*$')
 _DerivedDatatypes.append(Name)
 
 class NCName (Name):
-    """See http://www.w3.org/TR/1999/REC-xml-names-19990114/index.html#NT-NCName"""
+    """XMLSchema datatype U{NCName<http:///www.w3.org/TR/xmlschema-2/#NCName>}.
+
+    See U{http://www.w3.org/TR/1999/REC-xml-names-19990114/#NT-NCName}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('NCName')
     _ValidRE = re.compile('^[A-Za-z_][-_.A-Za-z0-9]*$')
 _DerivedDatatypes.append(NCName)
 
 class ID (NCName):
+    """XMLSchema datatype U{ID<http:///www.w3.org/TR/xmlschema-2/#ID>}."""
     # Lexical and value space match that of parent NCName
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('ID')
     pass
 _DerivedDatatypes.append(ID)
 
 class IDREF (NCName):
+    """XMLSchema datatype U{IDREF<http:///www.w3.org/TR/xmlschema-2/#IDREF>}."""
     # Lexical and value space match that of parent NCName
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('IDREF')
     pass
 _DerivedDatatypes.append(IDREF)
 
 class IDREFS (basis.STD_list):
+    """XMLSchema datatype U{IDREFS<http:///www.w3.org/TR/xmlschema-2/#IDREFS>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('IDREFS')
     _ItemType = IDREF
 _ListDatatypes.append(IDREFS)
 
 class ENTITY (NCName):
+    """XMLSchema datatype U{ENTITY<http:///www.w3.org/TR/xmlschema-2/#ENTITY>}."""
     # Lexical and value space match that of parent NCName; we're gonna
     # ignore the additional requirement that it be declared as an
     # unparsed entity
@@ -988,14 +973,13 @@ class ENTITY (NCName):
 _DerivedDatatypes.append(ENTITY)
 
 class ENTITIES (basis.STD_list):
+    """XMLSchema datatype U{ENTITIES<http:///www.w3.org/TR/xmlschema-2/#ENTITIES>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('ENTITIES')
     _ItemType = ENTITY
 _ListDatatypes.append(ENTITIES)
 
 class integer (basis.simpleTypeDefinition, types.LongType):
-    """integer.
-
-    http://www.w3.org/TR/xmlschema-2/#integer"""
+    """XMLSchema datatype U{integer<http://www.w3.org/TR/xmlschema-2/#integer>}."""
     _XsdBaseType = decimal
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('integer')
 
@@ -1006,18 +990,22 @@ class integer (basis.simpleTypeDefinition, types.LongType):
 _DerivedDatatypes.append(integer)
 
 class nonPositiveInteger (integer):
+    """XMLSchema datatype U{nonPositiveInteger<http://www.w3.org/TR/xmlschema-2/#nonPositiveInteger>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('nonPositiveInteger')
 _DerivedDatatypes.append(nonPositiveInteger)
 
 class negativeInteger (nonPositiveInteger):
+    """XMLSchema datatype U{negativeInteger<http://www.w3.org/TR/xmlschema-2/#negativeInteger>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('negativeInteger')
 _DerivedDatatypes.append(negativeInteger)
 
 class long (integer):
+    """XMLSchema datatype U{long<http://www.w3.org/TR/xmlschema-2/#long>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('long')
 _DerivedDatatypes.append(long)
 
 class int (basis.simpleTypeDefinition, types.IntType):
+    """XMLSchema datatype U{int<http://www.w3.org/TR/xmlschema-2/#int>}."""
     _XsdBaseType = long
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('int')
 
@@ -1029,34 +1017,42 @@ class int (basis.simpleTypeDefinition, types.IntType):
 _DerivedDatatypes.append(int)
 
 class short (int):
+    """XMLSchema datatype U{short<http://www.w3.org/TR/xmlschema-2/#short>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('short')
 _DerivedDatatypes.append(short)
 
 class byte (short):
+    """XMLSchema datatype U{byte<http://www.w3.org/TR/xmlschema-2/#byte>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('byte')
 _DerivedDatatypes.append(byte)
 
 class nonNegativeInteger (integer):
+    """XMLSchema datatype U{nonNegativeInteger<http://www.w3.org/TR/xmlschema-2/#nonNegativeInteger>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('nonNegativeInteger')
 _DerivedDatatypes.append(nonNegativeInteger)
 
 class unsignedLong (nonNegativeInteger):
+    """XMLSchema datatype U{unsignedLong<http://www.w3.org/TR/xmlschema-2/#unsignedLong>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('unsignedLong')
 _DerivedDatatypes.append(unsignedLong)
 
 class unsignedInt (unsignedLong):
+    """XMLSchema datatype U{unsignedInt<http://www.w3.org/TR/xmlschema-2/#unsignedInt>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('unsignedInt')
 _DerivedDatatypes.append(unsignedInt)
 
 class unsignedShort (unsignedInt):
+    """XMLSchema datatype U{unsignedShort<http://www.w3.org/TR/xmlschema-2/#unsignedShort>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('unsignedShort')
 _DerivedDatatypes.append(unsignedShort)
 
 class unsignedByte (unsignedShort):
+    """XMLSchema datatype U{unsignedByte<http://www.w3.org/TR/xmlschema-2/#unsignedByte>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('unsignedByte')
 _DerivedDatatypes.append(unsignedByte)
 
 class positiveInteger (nonNegativeInteger):
+    """XMLSchema datatype U{positiveInteger<http://www.w3.org/TR/xmlschema-2/#positiveInteger>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('positiveInteger')
 _DerivedDatatypes.append(positiveInteger)
 
@@ -1064,7 +1060,7 @@ import datatypes_facets
 import content
 
 class anyType (basis.complexTypeDefinition):
-    """http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/#key-urType"""
+    """XMLSchema datatype U{anyType<http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/#key-urType>}."""
     _ExpandedName = pyxb.namespace.XMLSchema.createExpandedName('anyType')
     _ContentTypeTag = basis.complexTypeDefinition._CT_MIXED
     _Abstract = False
@@ -1076,3 +1072,6 @@ class anyType (basis.complexTypeDefinition):
     __Inner = content.GroupSequence(content.ParticleModel(__Wildcard, min_occurs=0, max_occurs=None))
     _ContentModel = content.ParticleModel(__Inner, min_occurs=1, max_occurs=1)
 
+# anyType._IsUrType() is True; foo._IsUrType() for descendents of it
+# should be false.
+anyType._IsUrType = classmethod(lambda _c: _c == anyType)
