@@ -1,7 +1,8 @@
 # ./pyxb/bundles/common/raw/xsd_hfp.py
-# PyXB bindings for NamespaceModule
-# NSM:c53ce1768a4a63294762e2dee968b656ae0d44d0
-# Generated 2010-05-30 12:40:45.161470 by PyXB version 1.1.2
+# PyXB bindings for NM:c53ce1768a4a63294762e2dee968b656ae0d44d0
+# Generated 2011-09-09 14:09:01.769270 by PyXB version 1.1.3
+# Namespace http://www.w3.org/2001/XMLSchema-hasFacetAndProperty
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:79afc7be-6c12-11df-ab4d-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:2da1d3d8-db17-11e0-b761-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -53,20 +54,10 @@ class STD_ANON (pyxb.binding.datatypes.NMTOKEN, pyxb.binding.basis.enumeration_m
     _ExpandedName = None
     _Documentation = u'\n       \n       \n      '
 STD_ANON._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON, enum_prefix=None)
-STD_ANON.length = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'length')
-STD_ANON.minLength = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'minLength')
-STD_ANON.maxLength = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'maxLength')
-STD_ANON.pattern = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'pattern')
-STD_ANON.enumeration = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'enumeration')
-STD_ANON.maxInclusive = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'maxInclusive')
-STD_ANON.maxExclusive = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'maxExclusive')
-STD_ANON.minInclusive = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'minInclusive')
-STD_ANON.minExclusive = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'minExclusive')
-STD_ANON.totalDigits = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'totalDigits')
-STD_ANON.fractionDigits = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'fractionDigits')
-STD_ANON.whiteSpace = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'whiteSpace')
-STD_ANON.maxScale = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'maxScale')
-STD_ANON.minScale = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'minScale')
+STD_ANON.ordered = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'ordered', tag=u'ordered')
+STD_ANON.bounded = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'bounded', tag=u'bounded')
+STD_ANON.cardinality = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'cardinality', tag=u'cardinality')
+STD_ANON.numeric = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'numeric', tag=u'numeric')
 STD_ANON._InitializeFacetMap(STD_ANON._CF_enumeration)
 
 # Atomic SimpleTypeDefinition
@@ -80,10 +71,20 @@ class STD_ANON_ (pyxb.binding.datatypes.NMTOKEN, pyxb.binding.basis.enumeration_
     _ExpandedName = None
     _Documentation = u'\n       \n       \n      '
 STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_, enum_prefix=None)
-STD_ANON_.ordered = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'ordered')
-STD_ANON_.bounded = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'bounded')
-STD_ANON_.cardinality = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'cardinality')
-STD_ANON_.numeric = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'numeric')
+STD_ANON_.length = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'length', tag=u'length')
+STD_ANON_.minLength = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'minLength', tag=u'minLength')
+STD_ANON_.maxLength = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'maxLength', tag=u'maxLength')
+STD_ANON_.pattern = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'pattern', tag=u'pattern')
+STD_ANON_.enumeration = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'enumeration', tag=u'enumeration')
+STD_ANON_.maxInclusive = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'maxInclusive', tag=u'maxInclusive')
+STD_ANON_.maxExclusive = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'maxExclusive', tag=u'maxExclusive')
+STD_ANON_.minInclusive = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'minInclusive', tag=u'minInclusive')
+STD_ANON_.minExclusive = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'minExclusive', tag=u'minExclusive')
+STD_ANON_.totalDigits = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'totalDigits', tag=u'totalDigits')
+STD_ANON_.fractionDigits = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'fractionDigits', tag=u'fractionDigits')
+STD_ANON_.whiteSpace = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'whiteSpace', tag=u'whiteSpace')
+STD_ANON_.maxScale = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'maxScale', tag=u'maxScale')
+STD_ANON_.minScale = STD_ANON_._CF_enumeration.addEnumeration(unicode_value=u'minScale', tag=u'minScale')
 STD_ANON_._InitializeFacetMap(STD_ANON_._CF_enumeration)
 
 # Complex type CTD_ANON with content type EMPTY
@@ -99,12 +100,19 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     
     name = property(__name.value, __name.set, None, None)
 
+    
+    # Attribute value uses Python identifier value_
+    __value = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'value'), 'value_', '__httpwww_w3_org2001XMLSchema_hasFacetAndProperty_CTD_ANON_value', pyxb.binding.datatypes.normalizedString, required=True)
+    
+    value_ = property(__value.value, __value.set, None, None)
+
 
     _ElementMap = {
         
     }
     _AttributeMap = {
-        __name.name() : __name
+        __name.name() : __name,
+        __value.name() : __value
     }
 
 
@@ -117,12 +125,6 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _ExpandedName = None
     # Base type is pyxb.binding.datatypes.anyType
     
-    # Attribute value uses Python identifier value_
-    __value = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'value'), 'value_', '__httpwww_w3_org2001XMLSchema_hasFacetAndProperty_CTD_ANON__value', pyxb.binding.datatypes.normalizedString, required=True)
-    
-    value_ = property(__value.value, __value.set, None, None)
-
-    
     # Attribute name uses Python identifier name
     __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpwww_w3_org2001XMLSchema_hasFacetAndProperty_CTD_ANON__name', STD_ANON_, required=True)
     
@@ -133,14 +135,13 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
         
     }
     _AttributeMap = {
-        __value.name() : __value,
         __name.name() : __name
     }
 
 
 
-hasFacet = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasFacet'), CTD_ANON, documentation=u'\n   \n   \n   \n   ')
-Namespace.addCategoryObject('elementBinding', hasFacet.name().localName(), hasFacet)
-
-hasProperty = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasProperty'), CTD_ANON_, documentation=u'\n    \n    \n    \n   ')
+hasProperty = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasProperty'), CTD_ANON, documentation=u'\n    \n    \n    \n   ')
 Namespace.addCategoryObject('elementBinding', hasProperty.name().localName(), hasProperty)
+
+hasFacet = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'hasFacet'), CTD_ANON_, documentation=u'\n   \n   \n   \n   ')
+Namespace.addCategoryObject('elementBinding', hasFacet.name().localName(), hasFacet)
