@@ -1,7 +1,8 @@
 # ./pyxb/bundles/opengis/citygml/raw/cityFurniture.py
-# PyXB bindings for NamespaceModule
-# NSM:85f4207e01e7d893444721d35c9ca66d19225092
-# Generated 2010-05-30 12:42:10.281969 by PyXB version 1.1.2
+# PyXB bindings for NM:85f4207e01e7d893444721d35c9ca66d19225092
+# Generated 2011-09-09 14:19:21.046960 by PyXB version 1.1.3
+# Namespace http://www.opengis.net/citygml/cityfurniture/1.0
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:aba0cf02-6c12-11df-bbda-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9e253680-db18-11e0-80f3-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -44,17 +45,6 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
-# Atomic SimpleTypeDefinition
-class CityFurnitureClassType (pyxb.binding.datatypes.string):
-
-    """Class of a Furniture. The values of this type are defined in the XML file
-                CityFurnitureClassType.xml, according to the dictionary concept of GML3. """
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'CityFurnitureClassType')
-    _Documentation = u'Class of a Furniture. The values of this type are defined in the XML file\n                CityFurnitureClassType.xml, according to the dictionary concept of GML3. '
-CityFurnitureClassType._InitializeFacetMap()
-Namespace.addCategoryObject('typeBinding', u'CityFurnitureClassType', CityFurnitureClassType)
-
 # Atomic SimpleTypeDefinition
 class CityFurnitureFunctionType (pyxb.binding.datatypes.string):
 
@@ -66,6 +56,17 @@ class CityFurnitureFunctionType (pyxb.binding.datatypes.string):
 CityFurnitureFunctionType._InitializeFacetMap()
 Namespace.addCategoryObject('typeBinding', u'CityFurnitureFunctionType', CityFurnitureFunctionType)
 
+# Atomic SimpleTypeDefinition
+class CityFurnitureClassType (pyxb.binding.datatypes.string):
+
+    """Class of a Furniture. The values of this type are defined in the XML file
+                CityFurnitureClassType.xml, according to the dictionary concept of GML3. """
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'CityFurnitureClassType')
+    _Documentation = u'Class of a Furniture. The values of this type are defined in the XML file\n                CityFurnitureClassType.xml, according to the dictionary concept of GML3. '
+CityFurnitureClassType._InitializeFacetMap()
+Namespace.addCategoryObject('typeBinding', u'CityFurnitureClassType', CityFurnitureClassType)
+
 # Complex type CityFurnitureType with content type ELEMENT_ONLY
 class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectType):
     _TypeDefinition = None
@@ -74,38 +75,6 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'CityFurnitureType')
     # Base type is pyxb.bundles.opengis.citygml.base.AbstractCityObjectType
     
-    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod4ImplicitRepresentation uses Python identifier lod4ImplicitRepresentation
-    __lod4ImplicitRepresentation = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod4ImplicitRepresentation'), 'lod4ImplicitRepresentation', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod4ImplicitRepresentation', False)
-
-    
-    lod4ImplicitRepresentation = property(__lod4ImplicitRepresentation.value, __lod4ImplicitRepresentation.set, None, None)
-
-    
-    # Element location ({http://www.opengis.net/gml}location) inherited from {http://www.opengis.net/gml}AbstractFeatureType
-    
-    # Element externalReference ({http://www.opengis.net/citygml/1.0}externalReference) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}function uses Python identifier function
-    __function = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'function'), 'function', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0function', True)
-
-    
-    function = property(__function.value, __function.set, None, None)
-
-    
-    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod1Geometry uses Python identifier lod1Geometry
-    __lod1Geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod1Geometry'), 'lod1Geometry', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod1Geometry', False)
-
-    
-    lod1Geometry = property(__lod1Geometry.value, __lod1Geometry.set, None, None)
-
-    
-    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod2Geometry uses Python identifier lod2Geometry
-    __lod2Geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod2Geometry'), 'lod2Geometry', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod2Geometry', False)
-
-    
-    lod2Geometry = property(__lod2Geometry.value, __lod2Geometry.set, None, None)
-
-    
     # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod3Geometry uses Python identifier lod3Geometry
     __lod3Geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod3Geometry'), 'lod3Geometry', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod3Geometry', False)
 
@@ -113,7 +82,7 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     lod3Geometry = property(__lod3Geometry.value, __lod3Geometry.set, None, None)
 
     
-    # Element name ({http://www.opengis.net/gml}name) inherited from {http://www.opengis.net/gml}AbstractGMLType
+    # Element boundedBy ({http://www.opengis.net/gml}boundedBy) inherited from {http://www.opengis.net/gml}AbstractFeatureType
     
     # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod4Geometry uses Python identifier lod4Geometry
     __lod4Geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod4Geometry'), 'lod4Geometry', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod4Geometry', False)
@@ -122,6 +91,15 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     lod4Geometry = property(__lod4Geometry.value, __lod4Geometry.set, None, None)
 
     
+    # Element metaDataProperty ({http://www.opengis.net/gml}metaDataProperty) inherited from {http://www.opengis.net/gml}AbstractGMLType
+    
+    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod1TerrainIntersection uses Python identifier lod1TerrainIntersection
+    __lod1TerrainIntersection = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod1TerrainIntersection'), 'lod1TerrainIntersection', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod1TerrainIntersection', False)
+
+    
+    lod1TerrainIntersection = property(__lod1TerrainIntersection.value, __lod1TerrainIntersection.set, None, None)
+
+    
     # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod2TerrainIntersection uses Python identifier lod2TerrainIntersection
     __lod2TerrainIntersection = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod2TerrainIntersection'), 'lod2TerrainIntersection', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod2TerrainIntersection', False)
 
@@ -129,30 +107,6 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     lod2TerrainIntersection = property(__lod2TerrainIntersection.value, __lod2TerrainIntersection.set, None, None)
 
     
-    # Element boundedBy ({http://www.opengis.net/gml}boundedBy) inherited from {http://www.opengis.net/gml}AbstractFeatureType
-    
-    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}_GenericApplicationPropertyOfCityFurniture uses Python identifier GenericApplicationPropertyOfCityFurniture
-    __GenericApplicationPropertyOfCityFurniture = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityFurniture'), 'GenericApplicationPropertyOfCityFurniture', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0_GenericApplicationPropertyOfCityFurniture', True)
-
-    
-    GenericApplicationPropertyOfCityFurniture = property(__GenericApplicationPropertyOfCityFurniture.value, __GenericApplicationPropertyOfCityFurniture.set, None, None)
-
-    
-    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}class uses Python identifier class_
-    __class = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'class'), 'class_', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0class', False)
-
-    
-    class_ = property(__class.value, __class.set, None, None)
-
-    
-    # Element description ({http://www.opengis.net/gml}description) inherited from {http://www.opengis.net/gml}AbstractGMLType
-    
-    # Element creationDate ({http://www.opengis.net/citygml/1.0}creationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element generalizesTo ({http://www.opengis.net/citygml/1.0}generalizesTo) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element terminationDate ({http://www.opengis.net/citygml/1.0}terminationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
     # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod3TerrainIntersection uses Python identifier lod3TerrainIntersection
     __lod3TerrainIntersection = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod3TerrainIntersection'), 'lod3TerrainIntersection', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod3TerrainIntersection', False)
 
@@ -160,16 +114,7 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     lod3TerrainIntersection = property(__lod3TerrainIntersection.value, __lod3TerrainIntersection.set, None, None)
 
     
-    # Element metaDataProperty ({http://www.opengis.net/gml}metaDataProperty) inherited from {http://www.opengis.net/gml}AbstractGMLType
-    
-    # Element GenericApplicationPropertyOfCityObject ({http://www.opengis.net/citygml/1.0}_GenericApplicationPropertyOfCityObject) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod1TerrainIntersection uses Python identifier lod1TerrainIntersection
-    __lod1TerrainIntersection = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod1TerrainIntersection'), 'lod1TerrainIntersection', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod1TerrainIntersection', False)
-
-    
-    lod1TerrainIntersection = property(__lod1TerrainIntersection.value, __lod1TerrainIntersection.set, None, None)
-
+    # Element externalReference ({http://www.opengis.net/citygml/1.0}externalReference) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
     
     # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod4TerrainIntersection uses Python identifier lod4TerrainIntersection
     __lod4TerrainIntersection = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod4TerrainIntersection'), 'lod4TerrainIntersection', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod4TerrainIntersection', False)
@@ -178,6 +123,8 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     lod4TerrainIntersection = property(__lod4TerrainIntersection.value, __lod4TerrainIntersection.set, None, None)
 
     
+    # Element description ({http://www.opengis.net/gml}description) inherited from {http://www.opengis.net/gml}AbstractGMLType
+    
     # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod1ImplicitRepresentation uses Python identifier lod1ImplicitRepresentation
     __lod1ImplicitRepresentation = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod1ImplicitRepresentation'), 'lod1ImplicitRepresentation', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod1ImplicitRepresentation', False)
 
@@ -185,6 +132,13 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     lod1ImplicitRepresentation = property(__lod1ImplicitRepresentation.value, __lod1ImplicitRepresentation.set, None, None)
 
     
+    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}_GenericApplicationPropertyOfCityFurniture uses Python identifier GenericApplicationPropertyOfCityFurniture
+    __GenericApplicationPropertyOfCityFurniture = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityFurniture'), 'GenericApplicationPropertyOfCityFurniture', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0_GenericApplicationPropertyOfCityFurniture', True)
+
+    
+    GenericApplicationPropertyOfCityFurniture = property(__GenericApplicationPropertyOfCityFurniture.value, __GenericApplicationPropertyOfCityFurniture.set, None, None)
+
+    
     # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod2ImplicitRepresentation uses Python identifier lod2ImplicitRepresentation
     __lod2ImplicitRepresentation = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod2ImplicitRepresentation'), 'lod2ImplicitRepresentation', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod2ImplicitRepresentation', False)
 
@@ -199,25 +153,72 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
     lod3ImplicitRepresentation = property(__lod3ImplicitRepresentation.value, __lod3ImplicitRepresentation.set, None, None)
 
     
+    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod4ImplicitRepresentation uses Python identifier lod4ImplicitRepresentation
+    __lod4ImplicitRepresentation = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod4ImplicitRepresentation'), 'lod4ImplicitRepresentation', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod4ImplicitRepresentation', False)
+
+    
+    lod4ImplicitRepresentation = property(__lod4ImplicitRepresentation.value, __lod4ImplicitRepresentation.set, None, None)
+
+    
+    # Element creationDate ({http://www.opengis.net/citygml/1.0}creationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}class uses Python identifier class_
+    __class = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'class'), 'class_', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0class', False)
+
+    
+    class_ = property(__class.value, __class.set, None, None)
+
+    
+    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}function uses Python identifier function
+    __function = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'function'), 'function', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0function', True)
+
+    
+    function = property(__function.value, __function.set, None, None)
+
+    
+    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod1Geometry uses Python identifier lod1Geometry
+    __lod1Geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod1Geometry'), 'lod1Geometry', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod1Geometry', False)
+
+    
+    lod1Geometry = property(__lod1Geometry.value, __lod1Geometry.set, None, None)
+
+    
+    # Element GenericApplicationPropertyOfCityObject ({http://www.opengis.net/citygml/1.0}_GenericApplicationPropertyOfCityObject) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element location ({http://www.opengis.net/gml}location) inherited from {http://www.opengis.net/gml}AbstractFeatureType
+    
+    # Element {http://www.opengis.net/citygml/cityfurniture/1.0}lod2Geometry uses Python identifier lod2Geometry
+    __lod2Geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'lod2Geometry'), 'lod2Geometry', '__httpwww_opengis_netcitygmlcityfurniture1_0_CityFurnitureType_httpwww_opengis_netcitygmlcityfurniture1_0lod2Geometry', False)
+
+    
+    lod2Geometry = property(__lod2Geometry.value, __lod2Geometry.set, None, None)
+
+    
+    # Element name ({http://www.opengis.net/gml}name) inherited from {http://www.opengis.net/gml}AbstractGMLType
+    
+    # Element generalizesTo ({http://www.opengis.net/citygml/1.0}generalizesTo) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element terminationDate ({http://www.opengis.net/citygml/1.0}terminationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
     # Attribute id inherited from {http://www.opengis.net/gml}AbstractGMLType
 
     _ElementMap = pyxb.bundles.opengis.citygml.base.AbstractCityObjectType._ElementMap.copy()
     _ElementMap.update({
-        __lod4ImplicitRepresentation.name() : __lod4ImplicitRepresentation,
-        __function.name() : __function,
-        __lod1Geometry.name() : __lod1Geometry,
-        __lod2Geometry.name() : __lod2Geometry,
         __lod3Geometry.name() : __lod3Geometry,
         __lod4Geometry.name() : __lod4Geometry,
-        __lod2TerrainIntersection.name() : __lod2TerrainIntersection,
-        __GenericApplicationPropertyOfCityFurniture.name() : __GenericApplicationPropertyOfCityFurniture,
-        __class.name() : __class,
-        __lod3TerrainIntersection.name() : __lod3TerrainIntersection,
         __lod1TerrainIntersection.name() : __lod1TerrainIntersection,
+        __lod2TerrainIntersection.name() : __lod2TerrainIntersection,
+        __lod3TerrainIntersection.name() : __lod3TerrainIntersection,
         __lod4TerrainIntersection.name() : __lod4TerrainIntersection,
         __lod1ImplicitRepresentation.name() : __lod1ImplicitRepresentation,
+        __GenericApplicationPropertyOfCityFurniture.name() : __GenericApplicationPropertyOfCityFurniture,
         __lod2ImplicitRepresentation.name() : __lod2ImplicitRepresentation,
-        __lod3ImplicitRepresentation.name() : __lod3ImplicitRepresentation
+        __lod3ImplicitRepresentation.name() : __lod3ImplicitRepresentation,
+        __lod4ImplicitRepresentation.name() : __lod4ImplicitRepresentation,
+        __class.name() : __class,
+        __function.name() : __function,
+        __lod1Geometry.name() : __lod1Geometry,
+        __lod2Geometry.name() : __lod2Geometry
     })
     _AttributeMap = pyxb.bundles.opengis.citygml.base.AbstractCityObjectType._AttributeMap.copy()
     _AttributeMap.update({
@@ -226,43 +227,43 @@ class CityFurnitureType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectTyp
 Namespace.addCategoryObject('typeBinding', u'CityFurnitureType', CityFurnitureType)
 
 
-CityFurniture = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'CityFurniture'), CityFurnitureType)
-Namespace.addCategoryObject('elementBinding', CityFurniture.name().localName(), CityFurniture)
-
 GenericApplicationPropertyOfCityFurniture = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityFurniture'), pyxb.binding.datatypes.anyType, abstract=pyxb.binding.datatypes.boolean(1))
 Namespace.addCategoryObject('elementBinding', GenericApplicationPropertyOfCityFurniture.name().localName(), GenericApplicationPropertyOfCityFurniture)
 
+CityFurniture = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'CityFurniture'), CityFurnitureType)
+Namespace.addCategoryObject('elementBinding', CityFurniture.name().localName(), CityFurniture)
 
 
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod3Geometry'), pyxb.bundles.opengis.gml.GeometryPropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod4Geometry'), pyxb.bundles.opengis.gml.GeometryPropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod1TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod2TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod3TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod4TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod1ImplicitRepresentation'), pyxb.bundles.opengis.citygml.base.ImplicitRepresentationPropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityFurniture'), pyxb.binding.datatypes.anyType, abstract=pyxb.binding.datatypes.boolean(1), scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod2ImplicitRepresentation'), pyxb.bundles.opengis.citygml.base.ImplicitRepresentationPropertyType, scope=CityFurnitureType))
+
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod3ImplicitRepresentation'), pyxb.bundles.opengis.citygml.base.ImplicitRepresentationPropertyType, scope=CityFurnitureType))
+
 CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod4ImplicitRepresentation'), pyxb.bundles.opengis.citygml.base.ImplicitRepresentationPropertyType, scope=CityFurnitureType))
 
+CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'class'), CityFurnitureClassType, scope=CityFurnitureType))
+
 CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'function'), CityFurnitureFunctionType, scope=CityFurnitureType))
 
 CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod1Geometry'), pyxb.bundles.opengis.gml.GeometryPropertyType, scope=CityFurnitureType))
 
 CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod2Geometry'), pyxb.bundles.opengis.gml.GeometryPropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod3Geometry'), pyxb.bundles.opengis.gml.GeometryPropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod4Geometry'), pyxb.bundles.opengis.gml.GeometryPropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod2TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityFurniture'), pyxb.binding.datatypes.anyType, abstract=pyxb.binding.datatypes.boolean(1), scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'class'), CityFurnitureClassType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod3TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod1TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod4TerrainIntersection'), pyxb.bundles.opengis.gml.MultiCurvePropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod1ImplicitRepresentation'), pyxb.bundles.opengis.citygml.base.ImplicitRepresentationPropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod2ImplicitRepresentation'), pyxb.bundles.opengis.citygml.base.ImplicitRepresentationPropertyType, scope=CityFurnitureType))
-
-CityFurnitureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'lod3ImplicitRepresentation'), pyxb.bundles.opengis.citygml.base.ImplicitRepresentationPropertyType, scope=CityFurnitureType))
 CityFurnitureType._GroupModel_14 = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CityFurnitureType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/gml'), u'metaDataProperty')), min_occurs=0L, max_occurs=None),
     pyxb.binding.content.ParticleModel(CityFurnitureType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/gml'), u'description')), min_occurs=0L, max_occurs=1),
@@ -311,6 +312,6 @@ CityFurnitureType._GroupModel_10 = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CityFurnitureType._GroupModel_11, min_occurs=1, max_occurs=1),
     pyxb.binding.content.ParticleModel(CityFurnitureType._GroupModel_17, min_occurs=1, max_occurs=1)
     )
-CityFurnitureType._ContentModel_2 = pyxb.binding.content.ParticleModel(CityFurnitureType._GroupModel_10, min_occurs=1, max_occurs=1)
+CityFurnitureType._ContentModel = pyxb.binding.content.ParticleModel(CityFurnitureType._GroupModel_10, min_occurs=1, max_occurs=1)
 
 CityFurniture._setSubstitutionGroup(pyxb.bundles.opengis.citygml.base.CityObject)
