@@ -1,7 +1,8 @@
 # ./pyxb/bundles/opengis/citygml/raw/cityObjectGroup.py
-# PyXB bindings for NamespaceModule
-# NSM:e6932fbb101c5dffa115bf309ae8f51978213e97
-# Generated 2010-05-30 12:42:12.047849 by PyXB version 1.1.2
+# PyXB bindings for NM:e6932fbb101c5dffa115bf309ae8f51978213e97
+# Generated 2011-09-09 14:19:22.437339 by PyXB version 1.1.3
+# Namespace http://www.opengis.net/citygml/cityobjectgroup/1.0
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,11 +12,11 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:acad8a7a-6c12-11df-8939-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9efb83d4-db18-11e0-b0aa-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
-import pyxb.binding.datatypes
 import pyxb.bundles.opengis.citygml.base
+import pyxb.binding.datatypes
 import pyxb.bundles.opengis.gml
 import pyxb.bundles.opengis.misc.xlinks
 
@@ -45,6 +46,102 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
+# Complex type CityObjectGroupType with content type ELEMENT_ONLY
+class CityObjectGroupType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectType):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'CityObjectGroupType')
+    # Base type is pyxb.bundles.opengis.citygml.base.AbstractCityObjectType
+    
+    # Element name ({http://www.opengis.net/gml}name) inherited from {http://www.opengis.net/gml}AbstractGMLType
+    
+    # Element creationDate ({http://www.opengis.net/citygml/1.0}creationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}usage uses Python identifier usage
+    __usage = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'usage'), 'usage', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0usage', True)
+
+    
+    usage = property(__usage.value, __usage.set, None, None)
+
+    
+    # Element metaDataProperty ({http://www.opengis.net/gml}metaDataProperty) inherited from {http://www.opengis.net/gml}AbstractGMLType
+    
+    # Element location ({http://www.opengis.net/gml}location) inherited from {http://www.opengis.net/gml}AbstractFeatureType
+    
+    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}_GenericApplicationPropertyOfCityObjectGroup uses Python identifier GenericApplicationPropertyOfCityObjectGroup
+    __GenericApplicationPropertyOfCityObjectGroup = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityObjectGroup'), 'GenericApplicationPropertyOfCityObjectGroup', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0_GenericApplicationPropertyOfCityObjectGroup', True)
+
+    
+    GenericApplicationPropertyOfCityObjectGroup = property(__GenericApplicationPropertyOfCityObjectGroup.value, __GenericApplicationPropertyOfCityObjectGroup.set, None, None)
+
+    
+    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}class uses Python identifier class_
+    __class = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'class'), 'class_', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0class', False)
+
+    
+    class_ = property(__class.value, __class.set, None, None)
+
+    
+    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}groupMember uses Python identifier groupMember
+    __groupMember = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'groupMember'), 'groupMember', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0groupMember', True)
+
+    
+    groupMember = property(__groupMember.value, __groupMember.set, None, None)
+
+    
+    # Element generalizesTo ({http://www.opengis.net/citygml/1.0}generalizesTo) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}function uses Python identifier function
+    __function = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'function'), 'function', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0function', True)
+
+    
+    function = property(__function.value, __function.set, None, None)
+
+    
+    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}geometry uses Python identifier geometry
+    __geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'geometry'), 'geometry', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0geometry', False)
+
+    
+    geometry = property(__geometry.value, __geometry.set, None, None)
+
+    
+    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}parent uses Python identifier parent
+    __parent = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'parent'), 'parent', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0parent', False)
+
+    
+    parent = property(__parent.value, __parent.set, None, None)
+
+    
+    # Element externalReference ({http://www.opengis.net/citygml/1.0}externalReference) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element terminationDate ({http://www.opengis.net/citygml/1.0}terminationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element boundedBy ({http://www.opengis.net/gml}boundedBy) inherited from {http://www.opengis.net/gml}AbstractFeatureType
+    
+    # Element GenericApplicationPropertyOfCityObject ({http://www.opengis.net/citygml/1.0}_GenericApplicationPropertyOfCityObject) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
+    
+    # Element description ({http://www.opengis.net/gml}description) inherited from {http://www.opengis.net/gml}AbstractGMLType
+    
+    # Attribute id inherited from {http://www.opengis.net/gml}AbstractGMLType
+
+    _ElementMap = pyxb.bundles.opengis.citygml.base.AbstractCityObjectType._ElementMap.copy()
+    _ElementMap.update({
+        __usage.name() : __usage,
+        __GenericApplicationPropertyOfCityObjectGroup.name() : __GenericApplicationPropertyOfCityObjectGroup,
+        __class.name() : __class,
+        __groupMember.name() : __groupMember,
+        __function.name() : __function,
+        __geometry.name() : __geometry,
+        __parent.name() : __parent
+    })
+    _AttributeMap = pyxb.bundles.opengis.citygml.base.AbstractCityObjectType._AttributeMap.copy()
+    _AttributeMap.update({
+        
+    })
+Namespace.addCategoryObject('typeBinding', u'CityObjectGroupType', CityObjectGroupType)
+
+
 # Complex type CityObjectGroupMemberType with content type ELEMENT_ONLY
 class CityObjectGroupMemberType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
@@ -60,46 +157,28 @@ class CityObjectGroupMemberType (pyxb.binding.basis.complexTypeDefinition):
     CityObject = property(__CityObject.value, __CityObject.set, None, None)
 
     
-    # Attribute {http://www.w3.org/1999/xlink}show uses Python identifier show
-    __show = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'show'), 'show', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinkshow', pyxb.bundles.opengis.misc.xlinks.STD_ANON_)
-    
-    show = property(__show.value, __show.set, None, u"\n        The 'show' attribute is used to communicate the desired presentation \n        of the ending resource on traversal from the starting resource; it's \n        value should be treated as follows: \n        new - load ending resource in a new window, frame, pane, or other \n              presentation context\n        replace - load the resource in the same window, frame, pane, or \n                  other presentation context\n        embed - load ending resource in place of the presentation of the \n                starting resource\n        other - behavior is unconstrained; examine other markup in the \n                link for hints \n        none - behavior is unconstrained \n      ")
-
-    
     # Attribute {http://www.w3.org/1999/xlink}role uses Python identifier role_
     __role_ = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'role'), 'role_', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinkrole', pyxb.binding.datatypes.anyURI)
     
     role_ = property(__role_.value, __role_.set, None, None)
 
     
-    # Attribute {http://www.w3.org/1999/xlink}title uses Python identifier title
-    __title = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'title'), 'title', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinktitle', pyxb.binding.datatypes.string)
-    
-    title = property(__title.value, __title.set, None, None)
-
-    
-    # Attribute role uses Python identifier role
-    __role = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'role'), 'role', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_role', pyxb.binding.datatypes.string)
-    
-    role = property(__role.value, __role.set, None, None)
-
-    
     # Attribute {http://www.w3.org/1999/xlink}arcrole uses Python identifier arcrole
     __arcrole = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'arcrole'), 'arcrole', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinkarcrole', pyxb.binding.datatypes.anyURI)
     
     arcrole = property(__arcrole.value, __arcrole.set, None, None)
 
     
-    # Attribute {http://www.w3.org/1999/xlink}href uses Python identifier href
-    __href = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'href'), 'href', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinkhref', pyxb.binding.datatypes.anyURI)
+    # Attribute {http://www.w3.org/1999/xlink}show uses Python identifier show
+    __show = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'show'), 'show', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinkshow', pyxb.bundles.opengis.misc.xlinks.STD_ANON_)
     
-    href = property(__href.value, __href.set, None, None)
+    show = property(__show.value, __show.set, None, u"\n        The 'show' attribute is used to communicate the desired presentation \n        of the ending resource on traversal from the starting resource; it's \n        value should be treated as follows: \n        new - load ending resource in a new window, frame, pane, or other \n              presentation context\n        replace - load the resource in the same window, frame, pane, or \n                  other presentation context\n        embed - load ending resource in place of the presentation of the \n                starting resource\n        other - behavior is unconstrained; examine other markup in the \n                link for hints \n        none - behavior is unconstrained \n      ")
 
     
-    # Attribute {http://www.opengis.net/gml}remoteSchema uses Python identifier remoteSchema
-    __remoteSchema = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/gml'), u'remoteSchema'), 'remoteSchema', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_opengis_netgmlremoteSchema', pyxb.binding.datatypes.anyURI)
+    # Attribute {http://www.w3.org/1999/xlink}title uses Python identifier title
+    __title = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'title'), 'title', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinktitle', pyxb.binding.datatypes.string)
     
-    remoteSchema = property(__remoteSchema.value, __remoteSchema.set, None, u'Reference to an XML Schema fragment that specifies the content model of the propertys value. This is in conformance with the XML Schema Section 4.14 Referencing Schemas from Elsewhere.')
+    title = property(__title.value, __title.set, None, None)
 
     
     # Attribute {http://www.w3.org/1999/xlink}type uses Python identifier type
@@ -113,20 +192,38 @@ class CityObjectGroupMemberType (pyxb.binding.basis.complexTypeDefinition):
     
     actuate = property(__actuate.value, __actuate.set, None, u"\n        The 'actuate' attribute is used to communicate the desired timing \n        of traversal from the starting resource to the ending resource; \n        it's value should be treated as follows:\n        onLoad - traverse to the ending resource immediately on loading \n                 the starting resource \n        onRequest - traverse from the starting resource to the ending \n                    resource only on a post-loading event triggered for \n                    this purpose \n        other - behavior is unconstrained; examine other markup in link \n                for hints \n        none - behavior is unconstrained\n      ")
 
+    
+    # Attribute {http://www.opengis.net/gml}remoteSchema uses Python identifier remoteSchema
+    __remoteSchema = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/gml'), u'remoteSchema'), 'remoteSchema', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_opengis_netgmlremoteSchema', pyxb.binding.datatypes.anyURI)
+    
+    remoteSchema = property(__remoteSchema.value, __remoteSchema.set, None, u'Reference to an XML Schema fragment that specifies the content model of the propertys value. This is in conformance with the XML Schema Section 4.14 Referencing Schemas from Elsewhere.')
+
+    
+    # Attribute role uses Python identifier role
+    __role = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'role'), 'role', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_role', pyxb.binding.datatypes.string)
+    
+    role = property(__role.value, __role.set, None, None)
+
+    
+    # Attribute {http://www.w3.org/1999/xlink}href uses Python identifier href
+    __href = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'href'), 'href', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupMemberType_httpwww_w3_org1999xlinkhref', pyxb.binding.datatypes.anyURI)
+    
+    href = property(__href.value, __href.set, None, None)
+
 
     _ElementMap = {
         __CityObject.name() : __CityObject
     }
     _AttributeMap = {
-        __show.name() : __show,
         __role_.name() : __role_,
-        __title.name() : __title,
-        __role.name() : __role,
         __arcrole.name() : __arcrole,
-        __href.name() : __href,
-        __remoteSchema.name() : __remoteSchema,
+        __show.name() : __show,
+        __title.name() : __title,
         __type.name() : __type,
-        __actuate.name() : __actuate
+        __actuate.name() : __actuate,
+        __remoteSchema.name() : __remoteSchema,
+        __role.name() : __role,
+        __href.name() : __href
     }
 Namespace.addCategoryObject('typeBinding', u'CityObjectGroupMemberType', CityObjectGroupMemberType)
 
@@ -146,10 +243,10 @@ class CityObjectGroupParentType (pyxb.binding.basis.complexTypeDefinition):
     CityObject = property(__CityObject.value, __CityObject.set, None, None)
 
     
-    # Attribute {http://www.w3.org/1999/xlink}arcrole uses Python identifier arcrole
-    __arcrole = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'arcrole'), 'arcrole', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkarcrole', pyxb.binding.datatypes.anyURI)
+    # Attribute {http://www.w3.org/1999/xlink}actuate uses Python identifier actuate
+    __actuate = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'actuate'), 'actuate', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkactuate', pyxb.bundles.opengis.misc.xlinks.STD_ANON)
     
-    arcrole = property(__arcrole.value, __arcrole.set, None, None)
+    actuate = property(__actuate.value, __actuate.set, None, u"\n        The 'actuate' attribute is used to communicate the desired timing \n        of traversal from the starting resource to the ending resource; \n        it's value should be treated as follows:\n        onLoad - traverse to the ending resource immediately on loading \n                 the starting resource \n        onRequest - traverse from the starting resource to the ending \n                    resource only on a post-loading event triggered for \n                    this purpose \n        other - behavior is unconstrained; examine other markup in link \n                for hints \n        none - behavior is unconstrained\n      ")
 
     
     # Attribute {http://www.w3.org/1999/xlink}show uses Python identifier show
@@ -158,16 +255,10 @@ class CityObjectGroupParentType (pyxb.binding.basis.complexTypeDefinition):
     show = property(__show.value, __show.set, None, u"\n        The 'show' attribute is used to communicate the desired presentation \n        of the ending resource on traversal from the starting resource; it's \n        value should be treated as follows: \n        new - load ending resource in a new window, frame, pane, or other \n              presentation context\n        replace - load the resource in the same window, frame, pane, or \n                  other presentation context\n        embed - load ending resource in place of the presentation of the \n                starting resource\n        other - behavior is unconstrained; examine other markup in the \n                link for hints \n        none - behavior is unconstrained \n      ")
 
     
-    # Attribute {http://www.w3.org/1999/xlink}actuate uses Python identifier actuate
-    __actuate = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'actuate'), 'actuate', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkactuate', pyxb.bundles.opengis.misc.xlinks.STD_ANON)
+    # Attribute {http://www.w3.org/1999/xlink}role uses Python identifier role
+    __role = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'role'), 'role', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkrole', pyxb.binding.datatypes.anyURI)
     
-    actuate = property(__actuate.value, __actuate.set, None, u"\n        The 'actuate' attribute is used to communicate the desired timing \n        of traversal from the starting resource to the ending resource; \n        it's value should be treated as follows:\n        onLoad - traverse to the ending resource immediately on loading \n                 the starting resource \n        onRequest - traverse from the starting resource to the ending \n                    resource only on a post-loading event triggered for \n                    this purpose \n        other - behavior is unconstrained; examine other markup in link \n                for hints \n        none - behavior is unconstrained\n      ")
-
-    
-    # Attribute {http://www.w3.org/1999/xlink}title uses Python identifier title
-    __title = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'title'), 'title', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinktitle', pyxb.binding.datatypes.string)
-    
-    title = property(__title.value, __title.set, None, None)
+    role = property(__role.value, __role.set, None, None)
 
     
     # Attribute {http://www.w3.org/1999/xlink}type uses Python identifier type
@@ -176,10 +267,22 @@ class CityObjectGroupParentType (pyxb.binding.basis.complexTypeDefinition):
     type = property(__type.value, __type.set, None, None)
 
     
-    # Attribute {http://www.w3.org/1999/xlink}role uses Python identifier role
-    __role = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'role'), 'role', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkrole', pyxb.binding.datatypes.anyURI)
+    # Attribute {http://www.w3.org/1999/xlink}href uses Python identifier href
+    __href = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'href'), 'href', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkhref', pyxb.binding.datatypes.anyURI)
     
-    role = property(__role.value, __role.set, None, None)
+    href = property(__href.value, __href.set, None, None)
+
+    
+    # Attribute {http://www.w3.org/1999/xlink}title uses Python identifier title
+    __title = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'title'), 'title', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinktitle', pyxb.binding.datatypes.string)
+    
+    title = property(__title.value, __title.set, None, None)
+
+    
+    # Attribute {http://www.w3.org/1999/xlink}arcrole uses Python identifier arcrole
+    __arcrole = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'arcrole'), 'arcrole', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkarcrole', pyxb.binding.datatypes.anyURI)
+    
+    arcrole = property(__arcrole.value, __arcrole.set, None, None)
 
     
     # Attribute {http://www.opengis.net/gml}remoteSchema uses Python identifier remoteSchema
@@ -187,125 +290,23 @@ class CityObjectGroupParentType (pyxb.binding.basis.complexTypeDefinition):
     
     remoteSchema = property(__remoteSchema.value, __remoteSchema.set, None, u'Reference to an XML Schema fragment that specifies the content model of the propertys value. This is in conformance with the XML Schema Section 4.14 Referencing Schemas from Elsewhere.')
 
-    
-    # Attribute {http://www.w3.org/1999/xlink}href uses Python identifier href
-    __href = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/1999/xlink'), u'href'), 'href', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupParentType_httpwww_w3_org1999xlinkhref', pyxb.binding.datatypes.anyURI)
-    
-    href = property(__href.value, __href.set, None, None)
-
 
     _ElementMap = {
         __CityObject.name() : __CityObject
     }
     _AttributeMap = {
-        __arcrole.name() : __arcrole,
-        __show.name() : __show,
         __actuate.name() : __actuate,
-        __title.name() : __title,
-        __type.name() : __type,
+        __show.name() : __show,
         __role.name() : __role,
-        __remoteSchema.name() : __remoteSchema,
-        __href.name() : __href
+        __type.name() : __type,
+        __href.name() : __href,
+        __title.name() : __title,
+        __arcrole.name() : __arcrole,
+        __remoteSchema.name() : __remoteSchema
     }
 Namespace.addCategoryObject('typeBinding', u'CityObjectGroupParentType', CityObjectGroupParentType)
 
 
-# Complex type CityObjectGroupType with content type ELEMENT_ONLY
-class CityObjectGroupType (pyxb.bundles.opengis.citygml.base.AbstractCityObjectType):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'CityObjectGroupType')
-    # Base type is pyxb.bundles.opengis.citygml.base.AbstractCityObjectType
-    
-    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}_GenericApplicationPropertyOfCityObjectGroup uses Python identifier GenericApplicationPropertyOfCityObjectGroup
-    __GenericApplicationPropertyOfCityObjectGroup = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityObjectGroup'), 'GenericApplicationPropertyOfCityObjectGroup', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0_GenericApplicationPropertyOfCityObjectGroup', True)
-
-    
-    GenericApplicationPropertyOfCityObjectGroup = property(__GenericApplicationPropertyOfCityObjectGroup.value, __GenericApplicationPropertyOfCityObjectGroup.set, None, None)
-
-    
-    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}groupMember uses Python identifier groupMember
-    __groupMember = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'groupMember'), 'groupMember', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0groupMember', True)
-
-    
-    groupMember = property(__groupMember.value, __groupMember.set, None, None)
-
-    
-    # Element terminationDate ({http://www.opengis.net/citygml/1.0}terminationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element name ({http://www.opengis.net/gml}name) inherited from {http://www.opengis.net/gml}AbstractGMLType
-    
-    # Element GenericApplicationPropertyOfCityObject ({http://www.opengis.net/citygml/1.0}_GenericApplicationPropertyOfCityObject) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element metaDataProperty ({http://www.opengis.net/gml}metaDataProperty) inherited from {http://www.opengis.net/gml}AbstractGMLType
-    
-    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}usage uses Python identifier usage
-    __usage = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'usage'), 'usage', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0usage', True)
-
-    
-    usage = property(__usage.value, __usage.set, None, None)
-
-    
-    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}class uses Python identifier class_
-    __class = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'class'), 'class_', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0class', False)
-
-    
-    class_ = property(__class.value, __class.set, None, None)
-
-    
-    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}parent uses Python identifier parent
-    __parent = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'parent'), 'parent', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0parent', False)
-
-    
-    parent = property(__parent.value, __parent.set, None, None)
-
-    
-    # Element boundedBy ({http://www.opengis.net/gml}boundedBy) inherited from {http://www.opengis.net/gml}AbstractFeatureType
-    
-    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}geometry uses Python identifier geometry
-    __geometry = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'geometry'), 'geometry', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0geometry', False)
-
-    
-    geometry = property(__geometry.value, __geometry.set, None, None)
-
-    
-    # Element externalReference ({http://www.opengis.net/citygml/1.0}externalReference) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element {http://www.opengis.net/citygml/cityobjectgroup/1.0}function uses Python identifier function
-    __function = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'function'), 'function', '__httpwww_opengis_netcitygmlcityobjectgroup1_0_CityObjectGroupType_httpwww_opengis_netcitygmlcityobjectgroup1_0function', True)
-
-    
-    function = property(__function.value, __function.set, None, None)
-
-    
-    # Element description ({http://www.opengis.net/gml}description) inherited from {http://www.opengis.net/gml}AbstractGMLType
-    
-    # Element creationDate ({http://www.opengis.net/citygml/1.0}creationDate) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Element location ({http://www.opengis.net/gml}location) inherited from {http://www.opengis.net/gml}AbstractFeatureType
-    
-    # Element generalizesTo ({http://www.opengis.net/citygml/1.0}generalizesTo) inherited from {http://www.opengis.net/citygml/1.0}AbstractCityObjectType
-    
-    # Attribute id inherited from {http://www.opengis.net/gml}AbstractGMLType
-
-    _ElementMap = pyxb.bundles.opengis.citygml.base.AbstractCityObjectType._ElementMap.copy()
-    _ElementMap.update({
-        __GenericApplicationPropertyOfCityObjectGroup.name() : __GenericApplicationPropertyOfCityObjectGroup,
-        __groupMember.name() : __groupMember,
-        __usage.name() : __usage,
-        __class.name() : __class,
-        __parent.name() : __parent,
-        __geometry.name() : __geometry,
-        __function.name() : __function
-    })
-    _AttributeMap = pyxb.bundles.opengis.citygml.base.AbstractCityObjectType._AttributeMap.copy()
-    _AttributeMap.update({
-        
-    })
-Namespace.addCategoryObject('typeBinding', u'CityObjectGroupType', CityObjectGroupType)
-
-
 CityObjectGroup = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'CityObjectGroup'), CityObjectGroupType)
 Namespace.addCategoryObject('elementBinding', CityObjectGroup.name().localName(), CityObjectGroup)
 
@@ -314,35 +315,19 @@ Namespace.addCategoryObject('elementBinding', GenericApplicationPropertyOfCityOb
 
 
 
-CityObjectGroupMemberType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject'), pyxb.bundles.opengis.citygml.base.AbstractCityObjectType, abstract=pyxb.binding.datatypes.boolean(1), scope=CityObjectGroupMemberType))
-CityObjectGroupMemberType._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CityObjectGroupMemberType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject')), min_occurs=1, max_occurs=1)
-    )
-CityObjectGroupMemberType._ContentModel = pyxb.binding.content.ParticleModel(CityObjectGroupMemberType._GroupModel, min_occurs=0L, max_occurs=1)
-
-
-
-CityObjectGroupParentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject'), pyxb.bundles.opengis.citygml.base.AbstractCityObjectType, abstract=pyxb.binding.datatypes.boolean(1), scope=CityObjectGroupParentType))
-CityObjectGroupParentType._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CityObjectGroupParentType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject')), min_occurs=1, max_occurs=1)
-    )
-CityObjectGroupParentType._ContentModel = pyxb.binding.content.ParticleModel(CityObjectGroupParentType._GroupModel, min_occurs=0L, max_occurs=1)
-
-
+CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'usage'), pyxb.binding.datatypes.string, scope=CityObjectGroupType))
 
 CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'_GenericApplicationPropertyOfCityObjectGroup'), pyxb.binding.datatypes.anyType, abstract=pyxb.binding.datatypes.boolean(1), scope=CityObjectGroupType))
 
-CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'groupMember'), CityObjectGroupMemberType, scope=CityObjectGroupType))
-
-CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'usage'), pyxb.binding.datatypes.string, scope=CityObjectGroupType))
-
 CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'class'), pyxb.binding.datatypes.string, scope=CityObjectGroupType))
 
-CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'parent'), CityObjectGroupParentType, scope=CityObjectGroupType))
+CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'groupMember'), CityObjectGroupMemberType, scope=CityObjectGroupType))
+
+CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'function'), pyxb.binding.datatypes.string, scope=CityObjectGroupType))
 
 CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'geometry'), pyxb.bundles.opengis.gml.GeometryPropertyType, scope=CityObjectGroupType))
 
-CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'function'), pyxb.binding.datatypes.string, scope=CityObjectGroupType))
+CityObjectGroupType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'parent'), CityObjectGroupParentType, scope=CityObjectGroupType))
 CityObjectGroupType._GroupModel_14 = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CityObjectGroupType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/gml'), u'metaDataProperty')), min_occurs=0L, max_occurs=None),
     pyxb.binding.content.ParticleModel(CityObjectGroupType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/gml'), u'description')), min_occurs=0L, max_occurs=1),
@@ -383,6 +368,22 @@ CityObjectGroupType._GroupModel_10 = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CityObjectGroupType._GroupModel_11, min_occurs=1, max_occurs=1),
     pyxb.binding.content.ParticleModel(CityObjectGroupType._GroupModel_17, min_occurs=1, max_occurs=1)
     )
-CityObjectGroupType._ContentModel_2 = pyxb.binding.content.ParticleModel(CityObjectGroupType._GroupModel_10, min_occurs=1, max_occurs=1)
+CityObjectGroupType._ContentModel = pyxb.binding.content.ParticleModel(CityObjectGroupType._GroupModel_10, min_occurs=1, max_occurs=1)
+
+
+
+CityObjectGroupMemberType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject'), pyxb.bundles.opengis.citygml.base.AbstractCityObjectType, abstract=pyxb.binding.datatypes.boolean(1), scope=CityObjectGroupMemberType))
+CityObjectGroupMemberType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(CityObjectGroupMemberType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject')), min_occurs=1, max_occurs=1)
+    )
+CityObjectGroupMemberType._ContentModel = pyxb.binding.content.ParticleModel(CityObjectGroupMemberType._GroupModel, min_occurs=0L, max_occurs=1)
+
+
+
+CityObjectGroupParentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject'), pyxb.bundles.opengis.citygml.base.AbstractCityObjectType, abstract=pyxb.binding.datatypes.boolean(1), scope=CityObjectGroupParentType))
+CityObjectGroupParentType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(CityObjectGroupParentType._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.opengis.net/citygml/1.0'), u'_CityObject')), min_occurs=1, max_occurs=1)
+    )
+CityObjectGroupParentType._ContentModel = pyxb.binding.content.ParticleModel(CityObjectGroupParentType._GroupModel, min_occurs=0L, max_occurs=1)
 
 CityObjectGroup._setSubstitutionGroup(pyxb.bundles.opengis.citygml.base.CityObject)
