@@ -1,7 +1,8 @@
 # ./pyxb/bundles/opengis/iso19139/raw/gsr.py
-# PyXB bindings for NamespaceModule
-# NSM:5aaaf474613b31707b26b95522eb65602c2f6b28
-# Generated 2010-05-30 12:41:17.501928 by PyXB version 1.1.2
+# PyXB bindings for NM:5aaaf474613b31707b26b95522eb65602c2f6b28
+# Generated 2011-09-09 14:18:39.840525 by PyXB version 1.1.3
+# Namespace http://www.isotc211.org/2005/gsr [xmlns:gsr]
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:8b000326-6c12-11df-aa11-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:849cfa04-db18-11e0-91a4-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.bundles.opengis.raw._nsgroup
