@@ -1,7 +1,8 @@
 # ./pyxb/bundles/opengis/raw/_dct.py
-# PyXB bindings for NamespaceModule
-# NSM:62e52a6e1b0d23522982e9c2905e5cb67ad01951
-# Generated 2010-05-30 12:42:03.699939 by PyXB version 1.1.2
+# PyXB bindings for NM:62e52a6e1b0d23522982e9c2905e5cb67ad01951
+# Generated 2011-09-09 14:19:15.800919 by PyXB version 1.1.3
+# Namespace http://purl.org/dc/terms/ [xmlns:dct]
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:a86d0ec2-6c12-11df-8d3e-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9b8fedac-db18-11e0-abb2-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.bundles.opengis.raw._nsgroup_2
@@ -41,39 +42,39 @@ def CreateFromDOM (node, default_namespace=None):
         default_namespace = Namespace.fallbackNamespace()
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
-from pyxb.bundles.opengis.raw._nsgroup_2 import isPartOf # {http://purl.org/dc/terms/}isPartOf
-from pyxb.bundles.opengis.raw._nsgroup_2 import valid # {http://purl.org/dc/terms/}valid
-from pyxb.bundles.opengis.raw._nsgroup_2 import license # {http://purl.org/dc/terms/}license
-from pyxb.bundles.opengis.raw._nsgroup_2 import requires # {http://purl.org/dc/terms/}requires
-from pyxb.bundles.opengis.raw._nsgroup_2 import extent # {http://purl.org/dc/terms/}extent
-from pyxb.bundles.opengis.raw._nsgroup_2 import provenance # {http://purl.org/dc/terms/}provenance
-from pyxb.bundles.opengis.raw._nsgroup_2 import replaces # {http://purl.org/dc/terms/}replaces
-from pyxb.bundles.opengis.raw._nsgroup_2 import rightsHolder # {http://purl.org/dc/terms/}rightsHolder
-from pyxb.bundles.opengis.raw._nsgroup_2 import references # {http://purl.org/dc/terms/}references
-from pyxb.bundles.opengis.raw._nsgroup_2 import accessRights # {http://purl.org/dc/terms/}accessRights
-from pyxb.bundles.opengis.raw._nsgroup_2 import alternative # {http://purl.org/dc/terms/}alternative
-from pyxb.bundles.opengis.raw._nsgroup_2 import available # {http://purl.org/dc/terms/}available
-from pyxb.bundles.opengis.raw._nsgroup_2 import bibliographicCitation # {http://purl.org/dc/terms/}bibliographicCitation
 from pyxb.bundles.opengis.raw._nsgroup_2 import conformsTo # {http://purl.org/dc/terms/}conformsTo
+from pyxb.bundles.opengis.raw._nsgroup_2 import mediator # {http://purl.org/dc/terms/}mediator
+from pyxb.bundles.opengis.raw._nsgroup_2 import modified # {http://purl.org/dc/terms/}modified
+from pyxb.bundles.opengis.raw._nsgroup_2 import accessRights # {http://purl.org/dc/terms/}accessRights
+from pyxb.bundles.opengis.raw._nsgroup_2 import provenance # {http://purl.org/dc/terms/}provenance
+from pyxb.bundles.opengis.raw._nsgroup_2 import references # {http://purl.org/dc/terms/}references
+from pyxb.bundles.opengis.raw._nsgroup_2 import isVersionOf # {http://purl.org/dc/terms/}isVersionOf
+from pyxb.bundles.opengis.raw._nsgroup_2 import requires # {http://purl.org/dc/terms/}requires
+from pyxb.bundles.opengis.raw._nsgroup_2 import rightsHolder # {http://purl.org/dc/terms/}rightsHolder
+from pyxb.bundles.opengis.raw._nsgroup_2 import spatial # {http://purl.org/dc/terms/}spatial
+from pyxb.bundles.opengis.raw._nsgroup_2 import tableOfContents # {http://purl.org/dc/terms/}tableOfContents
+from pyxb.bundles.opengis.raw._nsgroup_2 import license # {http://purl.org/dc/terms/}license
+from pyxb.bundles.opengis.raw._nsgroup_2 import temporal # {http://purl.org/dc/terms/}temporal
+from pyxb.bundles.opengis.raw._nsgroup_2 import valid # {http://purl.org/dc/terms/}valid
+from pyxb.bundles.opengis.raw._nsgroup_2 import isPartOf # {http://purl.org/dc/terms/}isPartOf
+from pyxb.bundles.opengis.raw._nsgroup_2 import bibliographicCitation # {http://purl.org/dc/terms/}bibliographicCitation
+from pyxb.bundles.opengis.raw._nsgroup_2 import audience # {http://purl.org/dc/terms/}audience
+from pyxb.bundles.opengis.raw._nsgroup_2 import available # {http://purl.org/dc/terms/}available
 from pyxb.bundles.opengis.raw._nsgroup_2 import created # {http://purl.org/dc/terms/}created
+from pyxb.bundles.opengis.raw._nsgroup_2 import replaces # {http://purl.org/dc/terms/}replaces
 from pyxb.bundles.opengis.raw._nsgroup_2 import dateAccepted # {http://purl.org/dc/terms/}dateAccepted
-from pyxb.bundles.opengis.raw._nsgroup_2 import educationLevel # {http://purl.org/dc/terms/}educationLevel
+from pyxb.bundles.opengis.raw._nsgroup_2 import dateCopyrighted # {http://purl.org/dc/terms/}dateCopyrighted
+from pyxb.bundles.opengis.raw._nsgroup_2 import alternative # {http://purl.org/dc/terms/}alternative
+from pyxb.bundles.opengis.raw._nsgroup_2 import hasPart # {http://purl.org/dc/terms/}hasPart
 from pyxb.bundles.opengis.raw._nsgroup_2 import dateSubmitted # {http://purl.org/dc/terms/}dateSubmitted
 from pyxb.bundles.opengis.raw._nsgroup_2 import hasFormat # {http://purl.org/dc/terms/}hasFormat
-from pyxb.bundles.opengis.raw._nsgroup_2 import hasPart # {http://purl.org/dc/terms/}hasPart
+from pyxb.bundles.opengis.raw._nsgroup_2 import abstract # {http://purl.org/dc/terms/}abstract
+from pyxb.bundles.opengis.raw._nsgroup_2 import extent # {http://purl.org/dc/terms/}extent
 from pyxb.bundles.opengis.raw._nsgroup_2 import hasVersion # {http://purl.org/dc/terms/}hasVersion
+from pyxb.bundles.opengis.raw._nsgroup_2 import medium # {http://purl.org/dc/terms/}medium
 from pyxb.bundles.opengis.raw._nsgroup_2 import isFormatOf # {http://purl.org/dc/terms/}isFormatOf
 from pyxb.bundles.opengis.raw._nsgroup_2 import isReferencedBy # {http://purl.org/dc/terms/}isReferencedBy
-from pyxb.bundles.opengis.raw._nsgroup_2 import isReplacedBy # {http://purl.org/dc/terms/}isReplacedBy
-from pyxb.bundles.opengis.raw._nsgroup_2 import spatial # {http://purl.org/dc/terms/}spatial
-from pyxb.bundles.opengis.raw._nsgroup_2 import issued # {http://purl.org/dc/terms/}issued
-from pyxb.bundles.opengis.raw._nsgroup_2 import mediator # {http://purl.org/dc/terms/}mediator
 from pyxb.bundles.opengis.raw._nsgroup_2 import isRequiredBy # {http://purl.org/dc/terms/}isRequiredBy
-from pyxb.bundles.opengis.raw._nsgroup_2 import medium # {http://purl.org/dc/terms/}medium
-from pyxb.bundles.opengis.raw._nsgroup_2 import modified # {http://purl.org/dc/terms/}modified
-from pyxb.bundles.opengis.raw._nsgroup_2 import audience # {http://purl.org/dc/terms/}audience
-from pyxb.bundles.opengis.raw._nsgroup_2 import abstract # {http://purl.org/dc/terms/}abstract
-from pyxb.bundles.opengis.raw._nsgroup_2 import tableOfContents # {http://purl.org/dc/terms/}tableOfContents
-from pyxb.bundles.opengis.raw._nsgroup_2 import dateCopyrighted # {http://purl.org/dc/terms/}dateCopyrighted
-from pyxb.bundles.opengis.raw._nsgroup_2 import isVersionOf # {http://purl.org/dc/terms/}isVersionOf
-from pyxb.bundles.opengis.raw._nsgroup_2 import temporal # {http://purl.org/dc/terms/}temporal
+from pyxb.bundles.opengis.raw._nsgroup_2 import isReplacedBy # {http://purl.org/dc/terms/}isReplacedBy
+from pyxb.bundles.opengis.raw._nsgroup_2 import issued # {http://purl.org/dc/terms/}issued
+from pyxb.bundles.opengis.raw._nsgroup_2 import educationLevel # {http://purl.org/dc/terms/}educationLevel
