@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/httpbind.py
-# PyXB bindings for NamespaceModule
-# NSM:700d4ca8e0588f8b897f9c60d123e08fa4d56b36
-# Generated 2010-05-30 12:40:48.595906 by PyXB version 1.1.2
+# PyXB bindings for NM:700d4ca8e0588f8b897f9c60d123e08fa4d56b36
+# Generated 2011-09-09 14:09:09.232470 by PyXB version 1.1.3
+# Namespace http://schemas.xmlsoap.org/wsdl/http/
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,11 +12,11 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7bbc4dac-6c12-11df-83f9-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:3214022e-db17-11e0-9a2b-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
-import pyxb.binding.datatypes
 import pyxb.bundles.wssplat.wsdl11
+import pyxb.binding.datatypes
 
 Namespace = pyxb.namespace.NamespaceForURI(u'http://schemas.xmlsoap.org/wsdl/http/', create_if_missing=True)
 Namespace.configureCategories(['typeBinding', 'elementBinding'])
@@ -43,6 +44,60 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
+# Complex type operationType with content type EMPTY
+class operationType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'operationType')
+    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
+    
+    # Attribute location uses Python identifier location
+    __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_operationType_location', pyxb.binding.datatypes.anyURI, required=True)
+    
+    location = property(__location.value, __location.set, None, None)
+
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+
+    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
+    _AttributeMap.update({
+        __location.name() : __location
+    })
+Namespace.addCategoryObject('typeBinding', u'operationType', operationType)
+
+
+# Complex type bindingType with content type EMPTY
+class bindingType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'bindingType')
+    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
+    
+    # Attribute verb uses Python identifier verb
+    __verb = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'verb'), 'verb', '__httpschemas_xmlsoap_orgwsdlhttp_bindingType_verb', pyxb.binding.datatypes.NMTOKEN, required=True)
+    
+    verb = property(__verb.value, __verb.set, None, None)
+
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+
+    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
+    _AttributeMap.update({
+        __verb.name() : __verb
+    })
+Namespace.addCategoryObject('typeBinding', u'bindingType', bindingType)
+
+
 # Complex type CTD_ANON with content type EMPTY
 class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
@@ -68,13 +123,13 @@ class addressType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'addressType')
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
     # Attribute location uses Python identifier location
     __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_addressType_location', pyxb.binding.datatypes.anyURI, required=True)
     
     location = property(__location.value, __location.set, None, None)
 
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -87,60 +142,6 @@ class addressType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
 Namespace.addCategoryObject('typeBinding', u'addressType', addressType)
 
 
-# Complex type bindingType with content type EMPTY
-class bindingType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'bindingType')
-    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
-    # Attribute verb uses Python identifier verb
-    __verb = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'verb'), 'verb', '__httpschemas_xmlsoap_orgwsdlhttp_bindingType_verb', pyxb.binding.datatypes.NMTOKEN, required=True)
-    
-    verb = property(__verb.value, __verb.set, None, None)
-
-
-    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
-    _AttributeMap.update({
-        __verb.name() : __verb
-    })
-Namespace.addCategoryObject('typeBinding', u'bindingType', bindingType)
-
-
-# Complex type operationType with content type EMPTY
-class operationType (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'operationType')
-    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
-    # Attribute location uses Python identifier location
-    __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'location'), 'location', '__httpschemas_xmlsoap_orgwsdlhttp_operationType_location', pyxb.binding.datatypes.anyURI, required=True)
-    
-    location = property(__location.value, __location.set, None, None)
-
-
-    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
-    _AttributeMap.update({
-        __location.name() : __location
-    })
-Namespace.addCategoryObject('typeBinding', u'operationType', operationType)
-
-
 # Complex type CTD_ANON_ with content type EMPTY
 class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
@@ -158,17 +159,17 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
 
 
 
-urlEncoded = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlEncoded'), CTD_ANON)
-Namespace.addCategoryObject('elementBinding', urlEncoded.name().localName(), urlEncoded)
-
-address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), addressType)
-Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
+operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), operationType)
+Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
 
 binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'binding'), bindingType)
 Namespace.addCategoryObject('elementBinding', binding.name().localName(), binding)
 
-operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), operationType)
-Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
-
-urlReplacement = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlReplacement'), CTD_ANON_)
+urlReplacement = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlReplacement'), CTD_ANON)
 Namespace.addCategoryObject('elementBinding', urlReplacement.name().localName(), urlReplacement)
+
+address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), addressType)
+Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
+
+urlEncoded = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'urlEncoded'), CTD_ANON_)
+Namespace.addCategoryObject('elementBinding', urlEncoded.name().localName(), urlEncoded)
