@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/soap11.py
-# PyXB bindings for NamespaceModule
-# NSM:124ab58ff634848548cf6d9d1320f856ff23519e
-# Generated 2010-05-30 12:40:49.494569 by PyXB version 1.1.2
+# PyXB bindings for NM:124ab58ff634848548cf6d9d1320f856ff23519e
+# Generated 2011-09-09 14:09:10.375506 by PyXB version 1.1.3
+# Namespace http://schemas.xmlsoap.org/soap/envelope/
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7c471608-6c12-11df-85c4-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:32be9d24-db17-11e0-9114-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -68,14 +69,14 @@ STD_ANON._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON._CF_pattern.addPattern(pattern=u'0|1')
 STD_ANON._InitializeFacetMap(STD_ANON._CF_pattern)
 
-# Complex type Body_ with content type ELEMENT_ONLY
-class Body_ (pyxb.binding.basis.complexTypeDefinition):
+# Complex type Header_ with content type ELEMENT_ONLY
+class Header_ (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Body')
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Header')
     # Base type is pyxb.binding.datatypes.anyType
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/'))
     _HasWildcardElement = True
 
     _ElementMap = {
@@ -84,7 +85,7 @@ class Body_ (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap = {
         
     }
-Namespace.addCategoryObject('typeBinding', u'Body', Body_)
+Namespace.addCategoryObject('typeBinding', u'Header', Header_)
 
 
 # Complex type Envelope_ with content type ELEMENT_ONLY
@@ -121,6 +122,73 @@ class Envelope_ (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'Envelope', Envelope_)
 
 
+# Complex type Body_ with content type ELEMENT_ONLY
+class Body_ (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Body')
+    # Base type is pyxb.binding.datatypes.anyType
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'Body', Body_)
+
+
+# Complex type Fault_ with content type ELEMENT_ONLY
+class Fault_ (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Fault')
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Element faultcode uses Python identifier faultcode
+    __faultcode = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'faultcode'), 'faultcode', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultcode', False)
+
+    
+    faultcode = property(__faultcode.value, __faultcode.set, None, None)
+
+    
+    # Element faultstring uses Python identifier faultstring
+    __faultstring = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'faultstring'), 'faultstring', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultstring', False)
+
+    
+    faultstring = property(__faultstring.value, __faultstring.set, None, None)
+
+    
+    # Element faultactor uses Python identifier faultactor
+    __faultactor = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'faultactor'), 'faultactor', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultactor', False)
+
+    
+    faultactor = property(__faultactor.value, __faultactor.set, None, None)
+
+    
+    # Element detail uses Python identifier detail
+    __detail = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'detail'), 'detail', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__detail', False)
+
+    
+    detail = property(__detail.value, __detail.set, None, None)
+
+
+    _ElementMap = {
+        __faultcode.name() : __faultcode,
+        __faultstring.name() : __faultstring,
+        __faultactor.name() : __faultactor,
+        __detail.name() : __detail
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'Fault', Fault_)
+
+
 # Complex type detail with content type ELEMENT_ONLY
 class detail (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
@@ -140,75 +208,8 @@ class detail (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'detail', detail)
 
 
-# Complex type Fault_ with content type ELEMENT_ONLY
-class Fault_ (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Fault')
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Element faultcode uses Python identifier faultcode
-    __faultcode = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'faultcode'), 'faultcode', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultcode', False)
-
-    
-    faultcode = property(__faultcode.value, __faultcode.set, None, None)
-
-    
-    # Element detail uses Python identifier detail
-    __detail = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'detail'), 'detail', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__detail', False)
-
-    
-    detail = property(__detail.value, __detail.set, None, None)
-
-    
-    # Element faultstring uses Python identifier faultstring
-    __faultstring = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'faultstring'), 'faultstring', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultstring', False)
-
-    
-    faultstring = property(__faultstring.value, __faultstring.set, None, None)
-
-    
-    # Element faultactor uses Python identifier faultactor
-    __faultactor = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(None, u'faultactor'), 'faultactor', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultactor', False)
-
-    
-    faultactor = property(__faultactor.value, __faultactor.set, None, None)
-
-
-    _ElementMap = {
-        __faultcode.name() : __faultcode,
-        __detail.name() : __detail,
-        __faultstring.name() : __faultstring,
-        __faultactor.name() : __faultactor
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'Fault', Fault_)
-
-
-# Complex type Header_ with content type ELEMENT_ONLY
-class Header_ (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Header')
-    # Base type is pyxb.binding.datatypes.anyType
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/'))
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'Header', Header_)
-
-
-Body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Body'), Body_)
-Namespace.addCategoryObject('elementBinding', Body.name().localName(), Body)
+Header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Header'), Header_)
+Namespace.addCategoryObject('elementBinding', Header.name().localName(), Header)
 
 Envelope = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Envelope'), Envelope_)
 Namespace.addCategoryObject('elementBinding', Envelope.name().localName(), Envelope)
@@ -216,14 +217,14 @@ Namespace.addCategoryObject('elementBinding', Envelope.name().localName(), Envel
 Fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Fault'), Fault_)
 Namespace.addCategoryObject('elementBinding', Fault.name().localName(), Fault)
 
-Header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Header'), Header_)
-Namespace.addCategoryObject('elementBinding', Header.name().localName(), Header)
+Body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Body'), Body_)
+Namespace.addCategoryObject('elementBinding', Body.name().localName(), Body)
 
 
-Body_._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
+Header_._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/')), min_occurs=0L, max_occurs=None)
     )
-Body_._ContentModel = pyxb.binding.content.ParticleModel(Body_._GroupModel, min_occurs=1, max_occurs=1)
+Header_._ContentModel = pyxb.binding.content.ParticleModel(Header_._GroupModel, min_occurs=1, max_occurs=1)
 
 
 
@@ -238,20 +239,20 @@ Envelope_._GroupModel = pyxb.binding.content.GroupSequence(
 Envelope_._ContentModel = pyxb.binding.content.ParticleModel(Envelope_._GroupModel, min_occurs=1, max_occurs=1)
 
 
-detail._GroupModel = pyxb.binding.content.GroupSequence(
+Body_._GroupModel = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
     )
-detail._ContentModel = pyxb.binding.content.ParticleModel(detail._GroupModel, min_occurs=1, max_occurs=1)
+Body_._ContentModel = pyxb.binding.content.ParticleModel(Body_._GroupModel, min_occurs=1, max_occurs=1)
 
 
 
 Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultcode'), pyxb.binding.datatypes.QName, scope=Fault_))
 
-Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'detail'), detail, scope=Fault_))
-
 Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultstring'), pyxb.binding.datatypes.string, scope=Fault_))
 
 Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultactor'), pyxb.binding.datatypes.anyURI, scope=Fault_))
+
+Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'detail'), detail, scope=Fault_))
 Fault_._GroupModel = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultcode')), min_occurs=1, max_occurs=1),
     pyxb.binding.content.ParticleModel(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultstring')), min_occurs=1, max_occurs=1),
@@ -261,7 +262,7 @@ Fault_._GroupModel = pyxb.binding.content.GroupSequence(
 Fault_._ContentModel = pyxb.binding.content.ParticleModel(Fault_._GroupModel, min_occurs=1, max_occurs=1)
 
 
-Header_._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/')), min_occurs=0L, max_occurs=None)
+detail._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
     )
-Header_._ContentModel = pyxb.binding.content.ParticleModel(Header_._GroupModel, min_occurs=1, max_occurs=1)
+detail._ContentModel = pyxb.binding.content.ParticleModel(detail._GroupModel, min_occurs=1, max_occurs=1)
