@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/soapbind11.py
-# PyXB bindings for NamespaceModule
-# NSM:2df158009b766a507448a09144cbc02d3d478843
-# Generated 2010-05-30 12:40:51.219651 by PyXB version 1.1.2
+# PyXB bindings for NM:2df158009b766a507448a09144cbc02d3d478843
+# Generated 2011-09-09 14:09:12.267395 by PyXB version 1.1.3
+# Namespace http://schemas.xmlsoap.org/wsdl/soap/
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7d493f5e-6c12-11df-a28a-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:33e06f66-db17-11e0-871d-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -43,32 +44,6 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
-# Atomic SimpleTypeDefinition
-class tStyleChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
-
-    """An atomic simple type."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tStyleChoice')
-    _Documentation = None
-tStyleChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=tStyleChoice, enum_prefix=None)
-tStyleChoice.rpc = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'rpc')
-tStyleChoice.document = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'document')
-tStyleChoice._InitializeFacetMap(tStyleChoice._CF_enumeration)
-Namespace.addCategoryObject('typeBinding', u'tStyleChoice', tStyleChoice)
-
-# Atomic SimpleTypeDefinition
-class useChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
-
-    """An atomic simple type."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'useChoice')
-    _Documentation = None
-useChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=useChoice, enum_prefix=None)
-useChoice.literal = useChoice._CF_enumeration.addEnumeration(unicode_value=u'literal')
-useChoice.encoded = useChoice._CF_enumeration.addEnumeration(unicode_value=u'encoded')
-useChoice._InitializeFacetMap(useChoice._CF_enumeration)
-Namespace.addCategoryObject('typeBinding', u'useChoice', useChoice)
-
 # List SimpleTypeDefinition
 # superclasses pyxb.binding.datatypes.anySimpleType
 class encodingStyle (pyxb.binding.basis.STD_list):
@@ -84,87 +59,31 @@ class encodingStyle (pyxb.binding.basis.STD_list):
 encodingStyle._InitializeFacetMap()
 Namespace.addCategoryObject('typeBinding', u'encodingStyle', encodingStyle)
 
-# Complex type tOperation with content type EMPTY
-class tOperation (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tOperation')
-    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
-    # Attribute style uses Python identifier style
-    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap_tOperation_style', tStyleChoice)
-    
-    style = property(__style.value, __style.set, None, None)
+# Atomic SimpleTypeDefinition
+class useChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
 
-    
-    # Attribute soapAction uses Python identifier soapAction
-    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
-    
-    soapAction = property(__soapAction.value, __soapAction.set, None, None)
+    """An atomic simple type."""
 
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'useChoice')
+    _Documentation = None
+useChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=useChoice, enum_prefix=None)
+useChoice.literal = useChoice._CF_enumeration.addEnumeration(unicode_value=u'literal', tag=u'literal')
+useChoice.encoded = useChoice._CF_enumeration.addEnumeration(unicode_value=u'encoded', tag=u'encoded')
+useChoice._InitializeFacetMap(useChoice._CF_enumeration)
+Namespace.addCategoryObject('typeBinding', u'useChoice', useChoice)
 
-    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
-    _AttributeMap.update({
-        __style.name() : __style,
-        __soapAction.name() : __soapAction
-    })
-Namespace.addCategoryObject('typeBinding', u'tOperation', tOperation)
+# Atomic SimpleTypeDefinition
+class tStyleChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
 
+    """An atomic simple type."""
 
-# Complex type tBody with content type EMPTY
-class tBody (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBody')
-    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
-    # Attribute parts uses Python identifier parts
-    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_parts', pyxb.binding.datatypes.NMTOKENS)
-    
-    parts = property(__parts.value, __parts.set, None, None)
-
-    
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_use', useChoice)
-    
-    use = property(__use.value, __use.set, None, None)
-
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_encodingStyle', encodingStyle)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-    
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-
-    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
-    _AttributeMap.update({
-        __parts.name() : __parts,
-        __use.name() : __use,
-        __encodingStyle.name() : __encodingStyle,
-        __namespace.name() : __namespace
-    })
-Namespace.addCategoryObject('typeBinding', u'tBody', tBody)
-
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tStyleChoice')
+    _Documentation = None
+tStyleChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=tStyleChoice, enum_prefix=None)
+tStyleChoice.rpc = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'rpc', tag=u'rpc')
+tStyleChoice.document = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'document', tag=u'document')
+tStyleChoice._InitializeFacetMap(tStyleChoice._CF_enumeration)
+Namespace.addCategoryObject('typeBinding', u'tStyleChoice', tStyleChoice)
 
 # Complex type tHeader with content type ELEMENT_ONLY
 class tHeader (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
@@ -181,10 +100,16 @@ class tHeader (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     headerfault = property(__headerfault.value, __headerfault.set, None, None)
 
     
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_use', useChoice, required=True)
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_message', pyxb.binding.datatypes.QName, required=True)
     
-    use = property(__use.value, __use.set, None, None)
+    message = property(__message.value, __message.set, None, None)
+
+    
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_part', pyxb.binding.datatypes.NMTOKEN, required=True)
+    
+    part = property(__part.value, __part.set, None, None)
 
     
     # Attribute namespace uses Python identifier namespace
@@ -193,25 +118,19 @@ class tHeader (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     namespace = property(__namespace.value, __namespace.set, None, None)
 
     
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_message', pyxb.binding.datatypes.QName, required=True)
-    
-    message = property(__message.value, __message.set, None, None)
-
-    
     # Attribute encodingStyle uses Python identifier encodingStyle
     __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_encodingStyle', encodingStyle)
     
     encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
 
     
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_part', pyxb.binding.datatypes.NMTOKEN, required=True)
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_use', useChoice, required=True)
     
-    part = property(__part.value, __part.set, None, None)
+    use = property(__use.value, __use.set, None, None)
 
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -219,11 +138,11 @@ class tHeader (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     _AttributeMap.update({
-        __use.name() : __use,
-        __namespace.name() : __namespace,
         __message.name() : __message,
+        __part.name() : __part,
+        __namespace.name() : __namespace,
         __encodingStyle.name() : __encodingStyle,
-        __part.name() : __part
+        __use.name() : __use
     })
 Namespace.addCategoryObject('typeBinding', u'tHeader', tHeader)
 
@@ -236,6 +155,12 @@ class tBinding (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBinding')
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
+    # Attribute style uses Python identifier style
+    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap_tBinding_style', tStyleChoice)
+    
+    style = property(__style.value, __style.set, None, None)
+
+    
     # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     
     # Attribute transport uses Python identifier transport
@@ -243,9 +168,37 @@ class tBinding (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     
     transport = property(__transport.value, __transport.set, None, None)
 
+
+    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
+    _AttributeMap.update({
+        __style.name() : __style,
+        __transport.name() : __transport
+    })
+Namespace.addCategoryObject('typeBinding', u'tBinding', tBinding)
+
+
+# Complex type tOperation with content type EMPTY
+class tOperation (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tOperation')
+    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
+    # Attribute soapAction uses Python identifier soapAction
+    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
+    
+    soapAction = property(__soapAction.value, __soapAction.set, None, None)
+
     
     # Attribute style uses Python identifier style
-    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap_tBinding_style', tStyleChoice)
+    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap_tOperation_style', tStyleChoice)
     
     style = property(__style.value, __style.set, None, None)
 
@@ -256,61 +209,58 @@ class tBinding (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     _AttributeMap.update({
-        __transport.name() : __transport,
+        __soapAction.name() : __soapAction,
         __style.name() : __style
     })
-Namespace.addCategoryObject('typeBinding', u'tBinding', tBinding)
+Namespace.addCategoryObject('typeBinding', u'tOperation', tOperation)
 
 
-# Complex type tHeaderFault with content type EMPTY
-class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
+# Complex type tBody with content type EMPTY
+class tBody (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
-    
-    part = property(__part.value, __part.set, None, None)
-
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_encodingStyle', encodingStyle)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-    
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
-    
-    message = property(__message.value, __message.set, None, None)
-
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBody')
+    # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
     # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_use', useChoice, required=True)
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_use', useChoice)
     
     use = property(__use.value, __use.set, None, None)
 
     
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
     # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_namespace', pyxb.binding.datatypes.anyURI)
     
     namespace = property(__namespace.value, __namespace.set, None, None)
 
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_encodingStyle', encodingStyle)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
 
-    _ElementMap = {
+    
+    # Attribute parts uses Python identifier parts
+    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_parts', pyxb.binding.datatypes.NMTOKENS)
+    
+    parts = property(__parts.value, __parts.set, None, None)
+
+
+    _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
+    _ElementMap.update({
         
-    }
-    _AttributeMap = {
-        __part.name() : __part,
-        __encodingStyle.name() : __encodingStyle,
-        __message.name() : __message,
+    })
+    _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
+    _AttributeMap.update({
         __use.name() : __use,
-        __namespace.name() : __namespace
-    }
-Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
+        __namespace.name() : __namespace,
+        __encodingStyle.name() : __encodingStyle,
+        __parts.name() : __parts
+    })
+Namespace.addCategoryObject('typeBinding', u'tBody', tBody)
 
 
 # Complex type tFaultRes with content type EMPTY
@@ -321,14 +271,6 @@ class tFaultRes (tBody):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFaultRes')
     # Base type is tBody
     
-    # Attribute parts is restricted from parent
-    
-    # Attribute parts uses Python identifier parts
-    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_parts', pyxb.binding.datatypes.NMTOKENS, prohibited=True)
-    
-    parts = property()
-
-    
     # Attribute encodingStyle is restricted from parent
     
     # Attribute encodingStyle uses Python identifier encodingStyle
@@ -360,6 +302,14 @@ class tFaultRes (tBody):
     
     namespace = property(__namespace.value, __namespace.set, None, None)
 
+    
+    # Attribute parts is restricted from parent
+    
+    # Attribute parts uses Python identifier parts
+    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_parts', pyxb.binding.datatypes.NMTOKENS, prohibited=True)
+    
+    parts = property()
+
 
     _ElementMap = tBody._ElementMap.copy()
     _ElementMap.update({
@@ -367,11 +317,11 @@ class tFaultRes (tBody):
     })
     _AttributeMap = tBody._AttributeMap.copy()
     _AttributeMap.update({
-        __parts.name() : __parts,
         __encodingStyle.name() : __encodingStyle,
         __required.name() : __required,
         __use.name() : __use,
-        __namespace.name() : __namespace
+        __namespace.name() : __namespace,
+        __parts.name() : __parts
     })
 Namespace.addCategoryObject('typeBinding', u'tFaultRes', tFaultRes)
 
@@ -384,13 +334,7 @@ class tFault (tFaultRes):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFault')
     # Base type is tFaultRes
     
-    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
-    
-    # Attribute name uses Python identifier name
-    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlsoap_tFault_name', pyxb.binding.datatypes.NCName, required=True)
-    
-    name = property(__name.value, __name.set, None, None)
-
+    # Attribute namespace_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
     
     # Attribute use_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
     
@@ -398,7 +342,13 @@ class tFault (tFaultRes):
     
     # Attribute parts_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
     
-    # Attribute namespace_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
+    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
+    
+    # Attribute name uses Python identifier name
+    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlsoap_tFault_name', pyxb.binding.datatypes.NCName, required=True)
+    
+    name = property(__name.value, __name.set, None, None)
+
 
     _ElementMap = tFaultRes._ElementMap.copy()
     _ElementMap.update({
@@ -411,6 +361,57 @@ class tFault (tFaultRes):
 Namespace.addCategoryObject('typeBinding', u'tFault', tFault)
 
 
+# Complex type tHeaderFault with content type EMPTY
+class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_use', useChoice, required=True)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_encodingStyle', encodingStyle)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
+    
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
+    
+    part = property(__part.value, __part.set, None, None)
+
+    
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
+    
+    message = property(__message.value, __message.set, None, None)
+
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        __use.name() : __use,
+        __encodingStyle.name() : __encodingStyle,
+        __part.name() : __part,
+        __message.name() : __message,
+        __namespace.name() : __namespace
+    }
+Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
+
+
 # Complex type tAddress with content type EMPTY
 class tAddress (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _TypeDefinition = None
@@ -419,13 +420,13 @@ class tAddress (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tAddress')
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
     # Attribute location uses Python identifier location
     __location = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'location'), 'location', '__httpschemas_xmlsoap_orgwsdlsoap_tAddress_location', pyxb.binding.datatypes.anyURI, required=True)
     
     location = property(__location.value, __location.set, None, None)
 
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -438,27 +439,27 @@ class tAddress (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
 Namespace.addCategoryObject('typeBinding', u'tAddress', tAddress)
 
 
-operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), tOperation)
-Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
-
-body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'body'), tBody)
-Namespace.addCategoryObject('elementBinding', body.name().localName(), body)
-
 header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), tHeader)
 Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 
 binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'binding'), tBinding)
 Namespace.addCategoryObject('elementBinding', binding.name().localName(), binding)
 
-headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
-Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
+operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), tOperation)
+Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
 
 fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'fault'), tFault)
 Namespace.addCategoryObject('elementBinding', fault.name().localName(), fault)
 
+headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
+Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
+
 address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), tAddress)
 Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
 
+body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'body'), tBody)
+Namespace.addCategoryObject('elementBinding', body.name().localName(), body)
+
 
 
 tHeader._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault, scope=tHeader))
