@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/soapbind12.py
-# PyXB bindings for NamespaceModule
-# NSM:fe6dee6f975d5202c12c3e364c8df804f68deab8
-# Generated 2010-05-30 12:40:51.717034 by PyXB version 1.1.2
+# PyXB bindings for NM:fe6dee6f975d5202c12c3e364c8df804f68deab8
+# Generated 2011-09-09 14:09:12.832903 by PyXB version 1.1.3
+# Namespace http://schemas.xmlsoap.org/wsdl/soap12/
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7d94b114-6c12-11df-981d-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:343612e0-db17-11e0-9503-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -43,6 +44,19 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
+# Atomic SimpleTypeDefinition
+class useChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
+
+    """An atomic simple type."""
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'useChoice')
+    _Documentation = None
+useChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=useChoice, enum_prefix=None)
+useChoice.literal = useChoice._CF_enumeration.addEnumeration(unicode_value=u'literal', tag=u'literal')
+useChoice.encoded = useChoice._CF_enumeration.addEnumeration(unicode_value=u'encoded', tag=u'encoded')
+useChoice._InitializeFacetMap(useChoice._CF_enumeration)
+Namespace.addCategoryObject('typeBinding', u'useChoice', useChoice)
+
 # List SimpleTypeDefinition
 # superclasses pyxb.binding.datatypes.anySimpleType
 class tParts (pyxb.binding.basis.STD_list):
@@ -56,19 +70,6 @@ class tParts (pyxb.binding.basis.STD_list):
 tParts._InitializeFacetMap()
 Namespace.addCategoryObject('typeBinding', u'tParts', tParts)
 
-# Atomic SimpleTypeDefinition
-class useChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
-
-    """An atomic simple type."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'useChoice')
-    _Documentation = None
-useChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=useChoice, enum_prefix=None)
-useChoice.literal = useChoice._CF_enumeration.addEnumeration(unicode_value=u'literal')
-useChoice.encoded = useChoice._CF_enumeration.addEnumeration(unicode_value=u'encoded')
-useChoice._InitializeFacetMap(useChoice._CF_enumeration)
-Namespace.addCategoryObject('typeBinding', u'useChoice', useChoice)
-
 # Atomic SimpleTypeDefinition
 class tStyleChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
 
@@ -77,8 +78,8 @@ class tStyleChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeratio
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tStyleChoice')
     _Documentation = None
 tStyleChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=tStyleChoice, enum_prefix=None)
-tStyleChoice.rpc = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'rpc')
-tStyleChoice.document = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'document')
+tStyleChoice.rpc = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'rpc', tag=u'rpc')
+tStyleChoice.document = tStyleChoice._CF_enumeration.addEnumeration(unicode_value=u'document', tag=u'document')
 tStyleChoice._InitializeFacetMap(tStyleChoice._CF_enumeration)
 Namespace.addCategoryObject('typeBinding', u'tStyleChoice', tStyleChoice)
 
@@ -112,31 +113,31 @@ class tBody (tExtensibilityElementOpenAttrs):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBody')
     # Base type is tExtensibilityElementOpenAttrs
     
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_encodingStyle', pyxb.binding.datatypes.anyURI)
     
-    # Attribute parts uses Python identifier parts
-    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts)
-    
-    parts = property(__parts.value, __parts.set, None, None)
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
 
     
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
     # Attribute use uses Python identifier use
     __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_use', useChoice)
     
     use = property(__use.value, __use.set, None, None)
 
     
+    # Attribute parts uses Python identifier parts
+    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts)
+    
+    parts = property(__parts.value, __parts.set, None, None)
+
+    
     # Attribute namespace uses Python identifier namespace
     __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_namespace', pyxb.binding.datatypes.anyURI)
     
     namespace = property(__namespace.value, __namespace.set, None, None)
 
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_encodingStyle', pyxb.binding.datatypes.anyURI)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
 
     _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
@@ -145,14 +146,129 @@ class tBody (tExtensibilityElementOpenAttrs):
     })
     _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
     _AttributeMap.update({
-        __parts.name() : __parts,
+        __encodingStyle.name() : __encodingStyle,
         __use.name() : __use,
-        __namespace.name() : __namespace,
-        __encodingStyle.name() : __encodingStyle
+        __parts.name() : __parts,
+        __namespace.name() : __namespace
     })
 Namespace.addCategoryObject('typeBinding', u'tBody', tBody)
 
 
+# Complex type tHeader with content type ELEMENT_ONLY
+class tHeader (tExtensibilityElementOpenAttrs):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeader')
+    # Base type is tExtensibilityElementOpenAttrs
+    
+    # Element {http://schemas.xmlsoap.org/wsdl/soap12/}headerfault uses Python identifier headerfault
+    __headerfault = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), 'headerfault', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_httpschemas_xmlsoap_orgwsdlsoap12headerfault', True)
+
+    
+    headerfault = property(__headerfault.value, __headerfault.set, None, None)
+
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_use', useChoice, required=True)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_encodingStyle', pyxb.binding.datatypes.anyURI)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
+    
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_message', pyxb.binding.datatypes.QName, required=True)
+    
+    message = property(__message.value, __message.set, None, None)
+
+    
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_part', pyxb.binding.datatypes.NMTOKEN, required=True)
+    
+    part = property(__part.value, __part.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
+
+    _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
+    _ElementMap.update({
+        __headerfault.name() : __headerfault
+    })
+    _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
+    _AttributeMap.update({
+        __use.name() : __use,
+        __namespace.name() : __namespace,
+        __encodingStyle.name() : __encodingStyle,
+        __message.name() : __message,
+        __part.name() : __part
+    })
+Namespace.addCategoryObject('typeBinding', u'tHeader', tHeader)
+
+
+# Complex type tHeaderFault with content type EMPTY
+class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
+    
+    message = property(__message.value, __message.set, None, None)
+
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_use', useChoice, required=True)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_encodingStyle', pyxb.binding.datatypes.anyURI)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+    
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
+    
+    part = property(__part.value, __part.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        __message.name() : __message,
+        __use.name() : __use,
+        __encodingStyle.name() : __encodingStyle,
+        __namespace.name() : __namespace,
+        __part.name() : __part
+    }
+Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
+
+
 # Complex type tFaultRes with content type EMPTY
 class tFaultRes (tBody):
     _TypeDefinition = None
@@ -161,6 +277,14 @@ class tFaultRes (tBody):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFaultRes')
     # Base type is tBody
     
+    # Attribute use is restricted from parent
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_use', useChoice)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
     # Attribute required is restricted from parent
     
     # Attribute {http://schemas.xmlsoap.org/wsdl/}required uses Python identifier required
@@ -169,14 +293,6 @@ class tFaultRes (tBody):
     required = property(__required.value, __required.set, None, None)
 
     
-    # Attribute parts is restricted from parent
-    
-    # Attribute parts uses Python identifier parts
-    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts, prohibited=True)
-    
-    parts = property()
-
-    
     # Attribute encodingStyle is restricted from parent
     
     # Attribute encodingStyle uses Python identifier encodingStyle
@@ -185,12 +301,12 @@ class tFaultRes (tBody):
     encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
 
     
-    # Attribute use is restricted from parent
+    # Attribute parts is restricted from parent
     
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_use', useChoice)
+    # Attribute parts uses Python identifier parts
+    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts, prohibited=True)
     
-    use = property(__use.value, __use.set, None, None)
+    parts = property()
 
     
     # Attribute namespace is restricted from parent
@@ -207,10 +323,10 @@ class tFaultRes (tBody):
     })
     _AttributeMap = tBody._AttributeMap.copy()
     _AttributeMap.update({
-        __required.name() : __required,
-        __parts.name() : __parts,
-        __encodingStyle.name() : __encodingStyle,
         __use.name() : __use,
+        __required.name() : __required,
+        __encodingStyle.name() : __encodingStyle,
+        __parts.name() : __parts,
         __namespace.name() : __namespace
     })
 Namespace.addCategoryObject('typeBinding', u'tFaultRes', tFaultRes)
@@ -226,19 +342,19 @@ class tFault (tFaultRes):
     
     # Attribute use_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
     
+    # Attribute required_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+    
+    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+    
     # Attribute name uses Python identifier name
     __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlsoap12_tFault_name', pyxb.binding.datatypes.NCName, required=True)
     
     name = property(__name.value, __name.set, None, None)
 
     
-    # Attribute parts_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
-    
-    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
-    
     # Attribute namespace_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
     
-    # Attribute required_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+    # Attribute parts_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
 
     _ElementMap = tFaultRes._ElementMap.copy()
     _ElementMap.update({
@@ -287,6 +403,14 @@ class tOperation (tExtensibilityElementOpenAttrs):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tOperation')
     # Base type is tExtensibilityElementOpenAttrs
     
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
+    # Attribute soapAction uses Python identifier soapAction
+    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap12_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
+    
+    soapAction = property(__soapAction.value, __soapAction.set, None, None)
+
+    
     # Attribute soapActionRequired uses Python identifier soapActionRequired
     __soapActionRequired = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapActionRequired'), 'soapActionRequired', '__httpschemas_xmlsoap_orgwsdlsoap12_tOperation_soapActionRequired', pyxb.binding.datatypes.boolean)
     
@@ -298,14 +422,6 @@ class tOperation (tExtensibilityElementOpenAttrs):
     
     style = property(__style.value, __style.set, None, None)
 
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
-    # Attribute soapAction uses Python identifier soapAction
-    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap12_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
-    
-    soapAction = property(__soapAction.value, __soapAction.set, None, None)
-
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
 
     _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
@@ -314,128 +430,13 @@ class tOperation (tExtensibilityElementOpenAttrs):
     })
     _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
     _AttributeMap.update({
+        __soapAction.name() : __soapAction,
         __soapActionRequired.name() : __soapActionRequired,
-        __style.name() : __style,
-        __soapAction.name() : __soapAction
+        __style.name() : __style
     })
 Namespace.addCategoryObject('typeBinding', u'tOperation', tOperation)
 
 
-# Complex type tHeader with content type ELEMENT_ONLY
-class tHeader (tExtensibilityElementOpenAttrs):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeader')
-    # Base type is tExtensibilityElementOpenAttrs
-    
-    # Element {http://schemas.xmlsoap.org/wsdl/soap12/}headerfault uses Python identifier headerfault
-    __headerfault = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), 'headerfault', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_httpschemas_xmlsoap_orgwsdlsoap12headerfault', True)
-
-    
-    headerfault = property(__headerfault.value, __headerfault.set, None, None)
-
-    
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_message', pyxb.binding.datatypes.QName, required=True)
-    
-    message = property(__message.value, __message.set, None, None)
-
-    
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_part', pyxb.binding.datatypes.NMTOKEN, required=True)
-    
-    part = property(__part.value, __part.set, None, None)
-
-    
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-    
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_use', useChoice, required=True)
-    
-    use = property(__use.value, __use.set, None, None)
-
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_encodingStyle', pyxb.binding.datatypes.anyURI)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
-
-    _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
-    _ElementMap.update({
-        __headerfault.name() : __headerfault
-    })
-    _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
-    _AttributeMap.update({
-        __message.name() : __message,
-        __part.name() : __part,
-        __namespace.name() : __namespace,
-        __use.name() : __use,
-        __encodingStyle.name() : __encodingStyle
-    })
-Namespace.addCategoryObject('typeBinding', u'tHeader', tHeader)
-
-
-# Complex type tHeaderFault with content type EMPTY
-class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
-    
-    part = property(__part.value, __part.set, None, None)
-
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_encodingStyle', pyxb.binding.datatypes.anyURI)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-    
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
-    
-    message = property(__message.value, __message.set, None, None)
-
-    
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_use', useChoice, required=True)
-    
-    use = property(__use.value, __use.set, None, None)
-
-    
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        __part.name() : __part,
-        __encodingStyle.name() : __encodingStyle,
-        __message.name() : __message,
-        __use.name() : __use,
-        __namespace.name() : __namespace
-    }
-Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
-
-
 # Complex type tBinding with content type EMPTY
 class tBinding (tExtensibilityElementOpenAttrs):
     _TypeDefinition = None
@@ -444,7 +445,11 @@ class tBinding (tExtensibilityElementOpenAttrs):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBinding')
     # Base type is tExtensibilityElementOpenAttrs
     
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    # Attribute style uses Python identifier style
+    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap12_tBinding_style', tStyleChoice)
+    
+    style = property(__style.value, __style.set, None, None)
+
     
     # Attribute transport uses Python identifier transport
     __transport = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'transport'), 'transport', '__httpschemas_xmlsoap_orgwsdlsoap12_tBinding_transport', pyxb.binding.datatypes.anyURI, required=True)
@@ -452,11 +457,7 @@ class tBinding (tExtensibilityElementOpenAttrs):
     transport = property(__transport.value, __transport.set, None, None)
 
     
-    # Attribute style uses Python identifier style
-    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap12_tBinding_style', tStyleChoice)
-    
-    style = property(__style.value, __style.set, None, None)
-
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
 
     _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
@@ -465,12 +466,21 @@ class tBinding (tExtensibilityElementOpenAttrs):
     })
     _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
     _AttributeMap.update({
-        __transport.name() : __transport,
-        __style.name() : __style
+        __style.name() : __style,
+        __transport.name() : __transport
     })
 Namespace.addCategoryObject('typeBinding', u'tBinding', tBinding)
 
 
+body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'body'), tBody)
+Namespace.addCategoryObject('elementBinding', body.name().localName(), body)
+
+header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), tHeader)
+Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
+
+headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
+Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
+
 fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'fault'), tFault)
 Namespace.addCategoryObject('elementBinding', fault.name().localName(), fault)
 
@@ -480,18 +490,9 @@ Namespace.addCategoryObject('elementBinding', address.name().localName(), addres
 operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), tOperation)
 Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
 
-header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), tHeader)
-Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
-
-body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'body'), tBody)
-Namespace.addCategoryObject('elementBinding', body.name().localName(), body)
-
 binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'binding'), tBinding)
 Namespace.addCategoryObject('elementBinding', binding.name().localName(), binding)
 
-headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
-Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
-
 
 
 tHeader._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault, scope=tHeader))
