@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/whttp.py
-# PyXB bindings for NamespaceModule
-# NSM:b6d8cfb74f55bcb68c30cab97a9555b1fa1c0cfa
-# Generated 2010-05-30 12:40:52.297185 by PyXB version 1.1.2
+# PyXB bindings for NM:b6d8cfb74f55bcb68c30cab97a9555b1fa1c0cfa
+# Generated 2011-09-09 14:09:13.422341 by PyXB version 1.1.3
+# Namespace http://www.w3.org/ns/wsdl/http
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7dee929c-6c12-11df-a1f9-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:349117d0-db17-11e0-a063-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -43,18 +44,6 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
-# Atomic SimpleTypeDefinition
-class versionType (pyxb.binding.datatypes.string):
-
-    """An atomic simple type."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'versionType')
-    _Documentation = None
-versionType._CF_pattern = pyxb.binding.facets.CF_pattern()
-versionType._CF_pattern.addPattern(pattern=u'[0-9]+\\.[0-9]+')
-versionType._InitializeFacetMap(versionType._CF_pattern)
-Namespace.addCategoryObject('typeBinding', u'versionType', versionType)
-
 # Atomic SimpleTypeDefinition
 class STD_ANON (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mixin):
 
@@ -63,7 +52,7 @@ class STD_ANON (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mix
     _ExpandedName = None
     _Documentation = None
 STD_ANON._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON, enum_prefix=None)
-STD_ANON.any = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'#any')
+STD_ANON.any = STD_ANON._CF_enumeration.addEnumeration(unicode_value=u'#any', tag=u'any')
 STD_ANON._InitializeFacetMap(STD_ANON._CF_enumeration)
 
 # Union SimpleTypeDefinition
@@ -76,23 +65,23 @@ class STD_ANON_ (pyxb.binding.basis.STD_union):
     _Documentation = None
 
     _MemberTypes = ( pyxb.binding.datatypes.int, STD_ANON, )
-STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_)
 STD_ANON_._CF_pattern = pyxb.binding.facets.CF_pattern()
+STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_)
 STD_ANON_.any = u'#any'                           # originally STD_ANON.any
-STD_ANON_._InitializeFacetMap(STD_ANON_._CF_enumeration,
-   STD_ANON_._CF_pattern)
+STD_ANON_._InitializeFacetMap(STD_ANON_._CF_pattern,
+   STD_ANON_._CF_enumeration)
 
 # Atomic SimpleTypeDefinition
-class httpTokenType (pyxb.binding.datatypes.string):
+class versionType (pyxb.binding.datatypes.string):
 
     """An atomic simple type."""
 
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'httpTokenType')
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'versionType')
     _Documentation = None
-httpTokenType._CF_pattern = pyxb.binding.facets.CF_pattern()
-httpTokenType._CF_pattern.addPattern(pattern=u"[!#-'*+\\-.0-9A-Z^-z|~]+")
-httpTokenType._InitializeFacetMap(httpTokenType._CF_pattern)
-Namespace.addCategoryObject('typeBinding', u'httpTokenType', httpTokenType)
+versionType._CF_pattern = pyxb.binding.facets.CF_pattern()
+versionType._CF_pattern.addPattern(pattern=u'[0-9]+\\.[0-9]+')
+versionType._InitializeFacetMap(versionType._CF_pattern)
+Namespace.addCategoryObject('typeBinding', u'versionType', versionType)
 
 # Atomic SimpleTypeDefinition
 class queryParameterType (pyxb.binding.datatypes.string):
@@ -116,10 +105,22 @@ class STD_ANON_2 (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_m
     _ExpandedName = None
     _Documentation = None
 STD_ANON_2._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_2, enum_prefix=None)
-STD_ANON_2.basic = STD_ANON_2._CF_enumeration.addEnumeration(unicode_value=u'basic')
-STD_ANON_2.digest = STD_ANON_2._CF_enumeration.addEnumeration(unicode_value=u'digest')
+STD_ANON_2.basic = STD_ANON_2._CF_enumeration.addEnumeration(unicode_value=u'basic', tag=u'basic')
+STD_ANON_2.digest = STD_ANON_2._CF_enumeration.addEnumeration(unicode_value=u'digest', tag=u'digest')
 STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_enumeration)
 
+# Atomic SimpleTypeDefinition
+class httpTokenType (pyxb.binding.datatypes.string):
+
+    """An atomic simple type."""
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'httpTokenType')
+    _Documentation = None
+httpTokenType._CF_pattern = pyxb.binding.facets.CF_pattern()
+httpTokenType._CF_pattern.addPattern(pattern=u"[!#-'*+\\-.0-9A-Z^-z|~]+")
+httpTokenType._InitializeFacetMap(httpTokenType._CF_pattern)
+Namespace.addCategoryObject('typeBinding', u'httpTokenType', httpTokenType)
+
 # Complex type CTD_ANON with content type ELEMENT_ONLY
 class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     _TypeDefinition = None
@@ -130,10 +131,10 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     
     # Element documentation ({http://www.w3.org/ns/wsdl}documentation) inherited from {http://www.w3.org/ns/wsdl}DocumentedType
     
-    # Attribute type uses Python identifier type
-    __type = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'type'), 'type', '__httpwww_w3_orgnswsdlhttp_CTD_ANON_type', pyxb.binding.datatypes.QName, required=True)
+    # Attribute name uses Python identifier name
+    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpwww_w3_orgnswsdlhttp_CTD_ANON_name', httpTokenType, required=True)
     
-    type = property(__type.value, __type.set, None, None)
+    name = property(__name.value, __name.set, None, None)
 
     
     # Attribute required uses Python identifier required
@@ -142,10 +143,10 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     required = property(__required.value, __required.set, None, None)
 
     
-    # Attribute name uses Python identifier name
-    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpwww_w3_orgnswsdlhttp_CTD_ANON_name', httpTokenType, required=True)
+    # Attribute type uses Python identifier type
+    __type = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'type'), 'type', '__httpwww_w3_orgnswsdlhttp_CTD_ANON_type', pyxb.binding.datatypes.QName, required=True)
     
-    name = property(__name.value, __name.set, None, None)
+    type = property(__type.value, __type.set, None, None)
 
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/wsdl'))
 
@@ -155,9 +156,9 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._AttributeMap.copy()
     _AttributeMap.update({
-        __type.name() : __type,
+        __name.name() : __name,
         __required.name() : __required,
-        __name.name() : __name
+        __type.name() : __type
     })
 
 
@@ -169,4 +170,4 @@ Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 CTD_ANON._GroupModel_ = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/ns/wsdl'), u'documentation')), min_occurs=0L, max_occurs=None)
     )
-CTD_ANON._ContentModel_ = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel_, min_occurs=1, max_occurs=1)
+CTD_ANON._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel_, min_occurs=1, max_occurs=1)
