@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/wsam.py
-# PyXB bindings for NamespaceModule
-# NSM:8412da32cb8f7a70943a9934e4bb13ceb5b27944
-# Generated 2010-05-30 12:40:56.555134 by PyXB version 1.1.2
+# PyXB bindings for NM:8412da32cb8f7a70943a9934e4bb13ceb5b27944
+# Generated 2011-09-09 14:18:20.149490 by PyXB version 1.1.3
+# Namespace http://www.w3.org/2007/02/addressing/metadata
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:807b2976-6c12-11df-8d47-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7a73ff46-db18-11e0-9503-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -43,24 +44,6 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
-# Complex type AttributedQNameType with content type SIMPLE
-class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = pyxb.binding.datatypes.QName
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
-    # Base type is pyxb.binding.datatypes.QName
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2007/02/addressing/metadata'))
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
-
-
 # Complex type CTD_ANON with content type EMPTY
 class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
@@ -79,8 +62,33 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
 
 
 
-# Complex type CTD_ANON_ with content type EMPTY
+# Complex type CTD_ANON_ with content type ELEMENT_ONLY
 class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = None
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Element {http://www.w3.org/2006/07/ws-policy}Policy uses Python identifier Policy
+    __Policy = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), 'Policy', '__httpwww_w3_org200702addressingmetadata_CTD_ANON__httpwww_w3_org200607ws_policyPolicy', False)
+
+    
+    Policy = property(__Policy.value, __Policy.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2007/02/addressing/metadata'))
+
+    _ElementMap = {
+        __Policy.name() : __Policy
+    }
+    _AttributeMap = {
+        
+    }
+
+
+
+# Complex type CTD_ANON_2 with content type EMPTY
+class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
@@ -97,29 +105,22 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
 
 
 
-# Complex type CTD_ANON_2 with content type ELEMENT_ONLY
-class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+# Complex type AttributedQNameType with content type SIMPLE
+class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = pyxb.binding.datatypes.QName
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
-    _ExpandedName = None
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Element {http://www.w3.org/2006/07/ws-policy}Policy uses Python identifier Policy
-    __Policy = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), 'Policy', '__httpwww_w3_org200702addressingmetadata_CTD_ANON_2_httpwww_w3_org200607ws_policyPolicy', False)
-
-    
-    Policy = property(__Policy.value, __Policy.set, None, None)
-
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
+    # Base type is pyxb.binding.datatypes.QName
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2007/02/addressing/metadata'))
 
     _ElementMap = {
-        __Policy.name() : __Policy
+        
     }
     _AttributeMap = {
         
     }
-
+Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
 
 
 # Complex type ServiceNameType with content type SIMPLE
@@ -146,25 +147,25 @@ class ServiceNameType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'ServiceNameType', ServiceNameType)
 
 
-InterfaceName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'InterfaceName'), AttributedQNameType)
-Namespace.addCategoryObject('elementBinding', InterfaceName.name().localName(), InterfaceName)
-
 NonAnonymousResponses = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'NonAnonymousResponses'), CTD_ANON)
 Namespace.addCategoryObject('elementBinding', NonAnonymousResponses.name().localName(), NonAnonymousResponses)
 
-AnonymousResponses = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AnonymousResponses'), CTD_ANON_)
+Addressing = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Addressing'), CTD_ANON_)
+Namespace.addCategoryObject('elementBinding', Addressing.name().localName(), Addressing)
+
+AnonymousResponses = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AnonymousResponses'), CTD_ANON_2)
 Namespace.addCategoryObject('elementBinding', AnonymousResponses.name().localName(), AnonymousResponses)
 
-Addressing = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Addressing'), CTD_ANON_2)
-Namespace.addCategoryObject('elementBinding', Addressing.name().localName(), Addressing)
+InterfaceName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'InterfaceName'), AttributedQNameType)
+Namespace.addCategoryObject('elementBinding', InterfaceName.name().localName(), InterfaceName)
 
 ServiceName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ServiceName'), ServiceNameType)
 Namespace.addCategoryObject('elementBinding', ServiceName.name().localName(), ServiceName)
 
 
 
-CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), pyxb.bundles.wssplat.wsp200607.CTD_ANON_3, scope=CTD_ANON_2))
-CTD_ANON_2._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy')), min_occurs=1, max_occurs=1)
+CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy'), pyxb.bundles.wssplat.wsp200607.CTD_ANON_, scope=CTD_ANON_))
+CTD_ANON_._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy'), u'Policy')), min_occurs=1, max_occurs=1)
     )
-CTD_ANON_2._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_2._GroupModel, min_occurs=1, max_occurs=1)
+CTD_ANON_._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel, min_occurs=1, max_occurs=1)
