@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/wsdli.py
-# PyXB bindings for NamespaceModule
-# NSM:9a7cf9fba316541758d5e40c615b77e27a9ce79d
-# Generated 2010-05-30 12:40:58.060794 by PyXB version 1.1.2
+# PyXB bindings for NM:9a7cf9fba316541758d5e40c615b77e27a9ce79d
+# Generated 2011-09-09 14:18:22.331832 by PyXB version 1.1.3
+# Namespace http://www.w3.org/ns/wsdl-instance
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:81644c6e-6c12-11df-b3a6-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7bc31a94-db18-11e0-b3d1-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
