@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/wsoap.py
-# PyXB bindings for NamespaceModule
-# NSM:3a38467dbfe17f8bf02ac4151ad87deda2d076d0
-# Generated 2010-05-30 12:40:57.091200 by PyXB version 1.1.2
+# PyXB bindings for NM:3a38467dbfe17f8bf02ac4151ad87deda2d076d0
+# Generated 2011-09-09 14:18:20.711494 by PyXB version 1.1.3
+# Namespace http://www.w3.org/ns/wsdl/soap
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:80c8a05c-6c12-11df-8035-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7ac70de4-db18-11e0-b5c7-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -43,6 +44,18 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
+# List SimpleTypeDefinition
+# superclasses pyxb.binding.datatypes.anySimpleType
+class STD_ANON (pyxb.binding.basis.STD_list):
+
+    """Simple type that is a list of pyxb.binding.datatypes.QName."""
+
+    _ExpandedName = None
+    _Documentation = None
+
+    _ItemType = pyxb.binding.datatypes.QName
+STD_ANON._InitializeFacetMap()
+
 # Atomic SimpleTypeDefinition
 class TokenAny (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mixin):
 
@@ -51,13 +64,29 @@ class TokenAny (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mix
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'TokenAny')
     _Documentation = None
 TokenAny._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=TokenAny, enum_prefix=None)
-TokenAny.any = TokenAny._CF_enumeration.addEnumeration(unicode_value=u'#any')
+TokenAny.any = TokenAny._CF_enumeration.addEnumeration(unicode_value=u'#any', tag=u'any')
 TokenAny._InitializeFacetMap(TokenAny._CF_enumeration)
 Namespace.addCategoryObject('typeBinding', u'TokenAny', TokenAny)
 
 # Union SimpleTypeDefinition
 # superclasses pyxb.binding.datatypes.anySimpleType
-class STD_ANON (pyxb.binding.basis.STD_union):
+class STD_ANON_ (pyxb.binding.basis.STD_union):
+
+    """Simple type that is a union of TokenAny, STD_ANON."""
+
+    _ExpandedName = None
+    _Documentation = None
+
+    _MemberTypes = ( TokenAny, STD_ANON, )
+STD_ANON_._CF_pattern = pyxb.binding.facets.CF_pattern()
+STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_)
+STD_ANON_.any = u'#any'                           # originally TokenAny.any
+STD_ANON_._InitializeFacetMap(STD_ANON_._CF_pattern,
+   STD_ANON_._CF_enumeration)
+
+# Union SimpleTypeDefinition
+# superclasses pyxb.binding.datatypes.anySimpleType
+class STD_ANON_2 (pyxb.binding.basis.STD_union):
 
     """Simple type that is a union of pyxb.binding.datatypes.QName, TokenAny."""
 
@@ -65,39 +94,11 @@ class STD_ANON (pyxb.binding.basis.STD_union):
     _Documentation = None
 
     _MemberTypes = ( pyxb.binding.datatypes.QName, TokenAny, )
-STD_ANON._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON)
-STD_ANON._CF_pattern = pyxb.binding.facets.CF_pattern()
-STD_ANON.any = u'#any'                            # originally TokenAny.any
-STD_ANON._InitializeFacetMap(STD_ANON._CF_enumeration,
-   STD_ANON._CF_pattern)
-
-# List SimpleTypeDefinition
-# superclasses pyxb.binding.datatypes.anySimpleType
-class STD_ANON_ (pyxb.binding.basis.STD_list):
-
-    """Simple type that is a list of pyxb.binding.datatypes.QName."""
-
-    _ExpandedName = None
-    _Documentation = None
-
-    _ItemType = pyxb.binding.datatypes.QName
-STD_ANON_._InitializeFacetMap()
-
-# Union SimpleTypeDefinition
-# superclasses pyxb.binding.datatypes.anySimpleType
-class STD_ANON_2 (pyxb.binding.basis.STD_union):
-
-    """Simple type that is a union of TokenAny, STD_ANON_."""
-
-    _ExpandedName = None
-    _Documentation = None
-
-    _MemberTypes = ( TokenAny, STD_ANON_, )
-STD_ANON_2._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_2)
 STD_ANON_2._CF_pattern = pyxb.binding.facets.CF_pattern()
+STD_ANON_2._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_2)
 STD_ANON_2.any = u'#any'                          # originally TokenAny.any
-STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_enumeration,
-   STD_ANON_2._CF_pattern)
+STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_pattern,
+   STD_ANON_2._CF_enumeration)
 
 # Complex type CTD_ANON with content type ELEMENT_ONLY
 class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
@@ -109,17 +110,17 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     
     # Element documentation ({http://www.w3.org/ns/wsdl}documentation) inherited from {http://www.w3.org/ns/wsdl}DocumentedType
     
-    # Attribute ref uses Python identifier ref
-    __ref = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'ref'), 'ref', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_ref', pyxb.binding.datatypes.anyURI, required=True)
-    
-    ref = property(__ref.value, __ref.set, None, None)
-
-    
     # Attribute required uses Python identifier required
     __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'required'), 'required', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_required', pyxb.binding.datatypes.boolean)
     
     required = property(__required.value, __required.set, None, None)
 
+    
+    # Attribute ref uses Python identifier ref
+    __ref = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'ref'), 'ref', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_ref', pyxb.binding.datatypes.anyURI, required=True)
+    
+    ref = property(__ref.value, __ref.set, None, None)
+
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/wsdl'))
 
     _ElementMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._ElementMap.copy()
@@ -128,8 +129,8 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._AttributeMap.copy()
     _AttributeMap.update({
-        __ref.name() : __ref,
-        __required.name() : __required
+        __required.name() : __required,
+        __ref.name() : __ref
     })
 
 
@@ -144,10 +145,10 @@ class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     
     # Element documentation ({http://www.w3.org/ns/wsdl}documentation) inherited from {http://www.w3.org/ns/wsdl}DocumentedType
     
-    # Attribute mustUnderstand uses Python identifier mustUnderstand
-    __mustUnderstand = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'mustUnderstand'), 'mustUnderstand', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__mustUnderstand', pyxb.binding.datatypes.boolean)
+    # Attribute element uses Python identifier element
+    __element = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'element'), 'element', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__element', pyxb.binding.datatypes.QName, required=True)
     
-    mustUnderstand = property(__mustUnderstand.value, __mustUnderstand.set, None, None)
+    element = property(__element.value, __element.set, None, None)
 
     
     # Attribute required uses Python identifier required
@@ -156,10 +157,10 @@ class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     required = property(__required.value, __required.set, None, None)
 
     
-    # Attribute element uses Python identifier element
-    __element = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'element'), 'element', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__element', pyxb.binding.datatypes.QName, required=True)
+    # Attribute mustUnderstand uses Python identifier mustUnderstand
+    __mustUnderstand = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'mustUnderstand'), 'mustUnderstand', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__mustUnderstand', pyxb.binding.datatypes.boolean)
     
-    element = property(__element.value, __element.set, None, None)
+    mustUnderstand = property(__mustUnderstand.value, __mustUnderstand.set, None, None)
 
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/wsdl'))
 
@@ -169,9 +170,9 @@ class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._AttributeMap.copy()
     _AttributeMap.update({
-        __mustUnderstand.name() : __mustUnderstand,
+        __element.name() : __element,
         __required.name() : __required,
-        __element.name() : __element
+        __mustUnderstand.name() : __mustUnderstand
     })
 
 
@@ -186,10 +187,10 @@ Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 CTD_ANON._GroupModel_ = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/ns/wsdl'), u'documentation')), min_occurs=0L, max_occurs=None)
     )
-CTD_ANON._ContentModel_ = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel_, min_occurs=1, max_occurs=1)
+CTD_ANON._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel_, min_occurs=1, max_occurs=1)
 
 
 CTD_ANON_._GroupModel_ = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://www.w3.org/ns/wsdl'), u'documentation')), min_occurs=0L, max_occurs=None)
     )
-CTD_ANON_._ContentModel_ = pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel_, min_occurs=1, max_occurs=1)
+CTD_ANON_._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel_, min_occurs=1, max_occurs=1)
