@@ -1,7 +1,8 @@
 # ./pyxb/bundles/wssplat/raw/wsp200607.py
-# PyXB bindings for NamespaceModule
-# NSM:f7a1b3ccf248600ac00f0ba01aeba7fdd42b4412
-# Generated 2010-05-30 12:40:55.427857 by PyXB version 1.1.2
+# PyXB bindings for NM:f7a1b3ccf248600ac00f0ba01aeba7fdd42b4412
+# Generated 2011-09-09 14:18:18.932004 by PyXB version 1.1.3
+# Namespace http://www.w3.org/2006/07/ws-policy
+
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +12,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7fceb31c-6c12-11df-9bcb-001636553c48')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:79b98ff8-db18-11e0-af05-001fbc013adc')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -54,67 +55,6 @@ class STD_ANON (pyxb.binding.basis.STD_list):
     _ItemType = pyxb.binding.datatypes.anyURI
 STD_ANON._InitializeFacetMap()
 
-# Complex type CTD_ANON with content type ELEMENT_ONLY
-class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = None
-    # Base type is pyxb.binding.datatypes.anyType
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-
-
-
-# Complex type CTD_ANON_ with content type ELEMENT_ONLY
-class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = None
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Element {http://www.w3.org/2006/07/ws-policy}Policy uses Python identifier Policy
-    __Policy = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyPolicy', True)
-
-    
-    Policy = property(__Policy.value, __Policy.set, None, None)
-
-    
-    # Element {http://www.w3.org/2006/07/ws-policy}AppliesTo uses Python identifier AppliesTo
-    __AppliesTo = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), 'AppliesTo', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyAppliesTo', False)
-
-    
-    AppliesTo = property(__AppliesTo.value, __AppliesTo.set, None, None)
-
-    
-    # Element {http://www.w3.org/2006/07/ws-policy}PolicyReference uses Python identifier PolicyReference
-    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyPolicyReference', True)
-
-    
-    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        __Policy.name() : __Policy,
-        __AppliesTo.name() : __AppliesTo,
-        __PolicyReference.name() : __PolicyReference
-    }
-    _AttributeMap = {
-        
-    }
-
-
-
 # Complex type OperatorContentType with content type ELEMENT_ONLY
 class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
@@ -123,13 +63,6 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'OperatorContentType')
     # Base type is pyxb.binding.datatypes.anyType
     
-    # Element {http://www.w3.org/2006/07/ws-policy}PolicyReference uses Python identifier PolicyReference
-    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyPolicyReference', True)
-
-    
-    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
-
-    
     # Element {http://www.w3.org/2006/07/ws-policy}ExactlyOne uses Python identifier ExactlyOne
     __ExactlyOne = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), 'ExactlyOne', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyExactlyOne', True)
 
@@ -137,6 +70,13 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     ExactlyOne = property(__ExactlyOne.value, __ExactlyOne.set, None, None)
 
     
+    # Element {http://www.w3.org/2006/07/ws-policy}PolicyReference uses Python identifier PolicyReference
+    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyPolicyReference', True)
+
+    
+    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
+
+    
     # Element {http://www.w3.org/2006/07/ws-policy}All uses Python identifier All
     __All = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'All'), 'All', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyAll', True)
 
@@ -153,8 +93,8 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     _HasWildcardElement = True
 
     _ElementMap = {
-        __PolicyReference.name() : __PolicyReference,
         __ExactlyOne.name() : __ExactlyOne,
+        __PolicyReference.name() : __PolicyReference,
         __All.name() : __All,
         __Policy.name() : __Policy
     }
@@ -164,8 +104,8 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'OperatorContentType', OperatorContentType)
 
 
-# Complex type CTD_ANON_2 with content type EMPTY
-class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
+# Complex type CTD_ANON with content type EMPTY
+class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
@@ -173,22 +113,22 @@ class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
     # Base type is pyxb.binding.datatypes.anyType
     
     # Attribute Digest uses Python identifier Digest
-    __Digest = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Digest'), 'Digest', '__httpwww_w3_org200607ws_policy_CTD_ANON_2_Digest', pyxb.binding.datatypes.base64Binary)
+    __Digest = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Digest'), 'Digest', '__httpwww_w3_org200607ws_policy_CTD_ANON_Digest', pyxb.binding.datatypes.base64Binary)
     
     Digest = property(__Digest.value, __Digest.set, None, None)
 
     
-    # Attribute URI uses Python identifier URI
-    __URI = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'URI'), 'URI', '__httpwww_w3_org200607ws_policy_CTD_ANON_2_URI', pyxb.binding.datatypes.anyURI, required=True)
-    
-    URI = property(__URI.value, __URI.set, None, None)
-
-    
     # Attribute DigestAlgorithm uses Python identifier DigestAlgorithm
-    __DigestAlgorithm = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'DigestAlgorithm'), 'DigestAlgorithm', '__httpwww_w3_org200607ws_policy_CTD_ANON_2_DigestAlgorithm', pyxb.binding.datatypes.anyURI, unicode_default=u'http://www.w3.org/2006/07/policy/Sha1Exc')
+    __DigestAlgorithm = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'DigestAlgorithm'), 'DigestAlgorithm', '__httpwww_w3_org200607ws_policy_CTD_ANON_DigestAlgorithm', pyxb.binding.datatypes.anyURI, unicode_default=u'http://www.w3.org/2006/07/policy/Sha1Exc')
     
     DigestAlgorithm = property(__DigestAlgorithm.value, __DigestAlgorithm.set, None, None)
 
+    
+    # Attribute URI uses Python identifier URI
+    __URI = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'URI'), 'URI', '__httpwww_w3_org200607ws_policy_CTD_ANON_URI', pyxb.binding.datatypes.anyURI, required=True)
+    
+    URI = property(__URI.value, __URI.set, None, None)
+
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
 
     _ElementMap = {
@@ -196,39 +136,39 @@ class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
     }
     _AttributeMap = {
         __Digest.name() : __Digest,
-        __URI.name() : __URI,
-        __DigestAlgorithm.name() : __DigestAlgorithm
+        __DigestAlgorithm.name() : __DigestAlgorithm,
+        __URI.name() : __URI
     }
 
 
 
-# Complex type CTD_ANON_3 with content type ELEMENT_ONLY
-class CTD_ANON_3 (OperatorContentType):
+# Complex type CTD_ANON_ with content type ELEMENT_ONLY
+class CTD_ANON_ (OperatorContentType):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
     # Base type is OperatorContentType
     
-    # Element PolicyReference ({http://www.w3.org/2006/07/ws-policy}PolicyReference) inherited from {http://www.w3.org/2006/07/ws-policy}OperatorContentType
-    
     # Element ExactlyOne ({http://www.w3.org/2006/07/ws-policy}ExactlyOne) inherited from {http://www.w3.org/2006/07/ws-policy}OperatorContentType
     
+    # Element PolicyReference ({http://www.w3.org/2006/07/ws-policy}PolicyReference) inherited from {http://www.w3.org/2006/07/ws-policy}OperatorContentType
+    
     # Element All ({http://www.w3.org/2006/07/ws-policy}All) inherited from {http://www.w3.org/2006/07/ws-policy}OperatorContentType
     
     # Element Policy ({http://www.w3.org/2006/07/ws-policy}Policy) inherited from {http://www.w3.org/2006/07/ws-policy}OperatorContentType
     
-    # Attribute Name uses Python identifier Name
-    __Name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Name'), 'Name', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_Name', pyxb.binding.datatypes.anyURI)
-    
-    Name = property(__Name.value, __Name.set, None, None)
-
-    
     # Attribute {http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd}Id uses Python identifier Id
-    __Id = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd'), u'Id'), 'Id', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_httpdocs_oasis_open_orgwss200401oasis_200401_wss_wssecurity_utility_1_0_xsdId', pyxb.binding.datatypes.ID)
+    __Id = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd'), u'Id'), 'Id', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpdocs_oasis_open_orgwss200401oasis_200401_wss_wssecurity_utility_1_0_xsdId', pyxb.binding.datatypes.ID)
     
     Id = property(__Id.value, __Id.set, None, u'\nThis global attribute supports annotating arbitrary elements with an ID.\n          ')
 
+    
+    # Attribute Name uses Python identifier Name
+    __Name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Name'), 'Name', '__httpwww_w3_org200607ws_policy_CTD_ANON__Name', pyxb.binding.datatypes.anyURI)
+    
+    Name = property(__Name.value, __Name.set, None, None)
+
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
     _HasWildcardElement = True
 
@@ -238,63 +178,100 @@ class CTD_ANON_3 (OperatorContentType):
     })
     _AttributeMap = OperatorContentType._AttributeMap.copy()
     _AttributeMap.update({
-        __Name.name() : __Name,
-        __Id.name() : __Id
+        __Id.name() : __Id,
+        __Name.name() : __Name
     })
 
 
 
-PolicyAttachment = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyAttachment'), CTD_ANON_)
-Namespace.addCategoryObject('elementBinding', PolicyAttachment.name().localName(), PolicyAttachment)
+# Complex type CTD_ANON_2 with content type ELEMENT_ONLY
+class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = None
+    # Base type is pyxb.binding.datatypes.anyType
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
+    _HasWildcardElement = True
 
-AppliesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON)
-Namespace.addCategoryObject('elementBinding', AppliesTo.name().localName(), AppliesTo)
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
 
-All = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType)
-Namespace.addCategoryObject('elementBinding', All.name().localName(), All)
 
-PolicyReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_2)
-Namespace.addCategoryObject('elementBinding', PolicyReference.name().localName(), PolicyReference)
 
-Policy = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3)
-Namespace.addCategoryObject('elementBinding', Policy.name().localName(), Policy)
+# Complex type CTD_ANON_3 with content type ELEMENT_ONLY
+class CTD_ANON_3 (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = None
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Element {http://www.w3.org/2006/07/ws-policy}PolicyReference uses Python identifier PolicyReference
+    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_httpwww_w3_org200607ws_policyPolicyReference', True)
+
+    
+    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
+
+    
+    # Element {http://www.w3.org/2006/07/ws-policy}AppliesTo uses Python identifier AppliesTo
+    __AppliesTo = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), 'AppliesTo', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_httpwww_w3_org200607ws_policyAppliesTo', False)
+
+    
+    AppliesTo = property(__AppliesTo.value, __AppliesTo.set, None, None)
+
+    
+    # Element {http://www.w3.org/2006/07/ws-policy}Policy uses Python identifier Policy
+    __Policy = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_httpwww_w3_org200607ws_policyPolicy', True)
+
+    
+    Policy = property(__Policy.value, __Policy.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        __PolicyReference.name() : __PolicyReference,
+        __AppliesTo.name() : __AppliesTo,
+        __Policy.name() : __Policy
+    }
+    _AttributeMap = {
+        
+    }
+
+
 
 ExactlyOne = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType)
 Namespace.addCategoryObject('elementBinding', ExactlyOne.name().localName(), ExactlyOne)
 
+All = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType)
+Namespace.addCategoryObject('elementBinding', All.name().localName(), All)
 
-CTD_ANON._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=1L, max_occurs=None)
-    )
-CTD_ANON._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel, min_occurs=1, max_occurs=1)
+PolicyReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON)
+Namespace.addCategoryObject('elementBinding', PolicyReference.name().localName(), PolicyReference)
+
+AppliesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_2)
+Namespace.addCategoryObject('elementBinding', AppliesTo.name().localName(), AppliesTo)
+
+PolicyAttachment = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyAttachment'), CTD_ANON_3)
+Namespace.addCategoryObject('elementBinding', PolicyAttachment.name().localName(), PolicyAttachment)
+
+Policy = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_)
+Namespace.addCategoryObject('elementBinding', Policy.name().localName(), Policy)
 
 
 
-CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=CTD_ANON_))
-
-CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON, scope=CTD_ANON_))
-
-CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_2, scope=CTD_ANON_))
-CTD_ANON_._GroupModel_ = pyxb.binding.content.GroupChoice(
-    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
-    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), min_occurs=1, max_occurs=1)
-    )
-CTD_ANON_._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo')), min_occurs=1, max_occurs=1),
-    pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel_, min_occurs=1, max_occurs=None),
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), min_occurs=0L, max_occurs=None)
-    )
-CTD_ANON_._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel, min_occurs=1, max_occurs=1)
-
-
-
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_2, scope=OperatorContentType))
-
 OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType, scope=OperatorContentType))
 
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, scope=OperatorContentType))
+
 OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType, scope=OperatorContentType))
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=OperatorContentType))
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_, scope=OperatorContentType))
 OperatorContentType._GroupModel_ = pyxb.binding.content.GroupChoice(
     pyxb.binding.content.ParticleModel(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
     pyxb.binding.content.ParticleModel(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), min_occurs=1, max_occurs=1),
@@ -308,14 +285,38 @@ OperatorContentType._GroupModel = pyxb.binding.content.GroupSequence(
 OperatorContentType._ContentModel = pyxb.binding.content.ParticleModel(OperatorContentType._GroupModel, min_occurs=1, max_occurs=1)
 
 
-CTD_ANON_3._GroupModel_ = pyxb.binding.content.GroupChoice(
-    pyxb.binding.content.ParticleModel(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
-    pyxb.binding.content.ParticleModel(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), min_occurs=1, max_occurs=1),
-    pyxb.binding.content.ParticleModel(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), min_occurs=1, max_occurs=1),
-    pyxb.binding.content.ParticleModel(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), min_occurs=1, max_occurs=1),
+CTD_ANON_._GroupModel_ = pyxb.binding.content.GroupChoice(
+    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), min_occurs=1, max_occurs=1),
     pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), min_occurs=1L, max_occurs=1L)
     )
+CTD_ANON_._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel_, min_occurs=0L, max_occurs=None)
+    )
+CTD_ANON_._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel, min_occurs=1, max_occurs=1)
+
+
+CTD_ANON_2._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=1L, max_occurs=None)
+    )
+CTD_ANON_2._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_2._GroupModel, min_occurs=1, max_occurs=1)
+
+
+
+CTD_ANON_3._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, scope=CTD_ANON_3))
+
+CTD_ANON_3._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_2, scope=CTD_ANON_3))
+
+CTD_ANON_3._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_, scope=CTD_ANON_3))
+CTD_ANON_3._GroupModel_ = pyxb.binding.content.GroupChoice(
+    pyxb.binding.content.ParticleModel(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), min_occurs=1, max_occurs=1)
+    )
 CTD_ANON_3._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(CTD_ANON_3._GroupModel_, min_occurs=0L, max_occurs=None)
+    pyxb.binding.content.ParticleModel(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_3._GroupModel_, min_occurs=1, max_occurs=None),
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), min_occurs=0L, max_occurs=None)
     )
 CTD_ANON_3._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_3._GroupModel, min_occurs=1, max_occurs=1)
