@@ -33,35 +33,57 @@ _UnderscoreSubstitute_re = re.compile(r'[- .]')
 _NonIdentifier_re = re.compile(r'[^a-zA-Z0-9_]')
 _PrefixUnderscore_re = re.compile(r'^_+')
 _PrefixDigit_re = re.compile(r'^\d+')
+_CamelCase_re = re.compile(r'_\w')
 
-def MakeIdentifier (s):
+def MakeIdentifier (s, camel_case=False):
     """Convert a string into something suitable to be a Python identifier.
 
     The string is converted to unicode; spaces and periods replaced by
-    underscores; non-printables stripped.  Furthermore, any leading
-    underscores are removed.  If the result begins with a digit, the
-    character 'n' is prepended.  If the result is the empty string,
-    the string 'emptyString' is substituted.
+    underscores; non-printable/non-ASCII stripped.  Furthermore, any
+    leading underscores are removed.  If the result begins with a
+    digit, the character 'n' is prepended.  If the result is the empty
+    string, the string 'emptyString' is substituted.
 
     No check is made for L{conflicts with keywords <DeconflictKeyword>}.
 
+    @keyword camel_case : If C{True}, any underscore in the result
+    string that is immediately followed by an alphanumeric is replaced
+    by the capitalized version of that alphanumeric.  Thus,
+    'one_or_two' becomes 'oneOrTwo'.  If C{False} (default), has no
+    effect.
+
     @rtype: C{str}
     """
-    s = _PrefixUnderscore_re.sub('', _NonIdentifier_re.sub('',_UnderscoreSubstitute_re.sub('_', str(s))))
+    s = _PrefixUnderscore_re.sub('', _NonIdentifier_re.sub('',_UnderscoreSubstitute_re.sub('_', unicode(s))))
+    if camel_case:
+        s = _CamelCase_re.sub(lambda _m: _m.group(0)[1].upper(), s)
     if _PrefixDigit_re.match(s):
         s = 'n' + s
     if 0 == len(s):
         s = 'emptyString'
     return s
 
-# Note that types like int and float are not keywords
-_Keywords = frozenset( ( "and", "del", "from", "not", "while", "as", "elif", "global",
-              "or", "with", "assert", "else", "if", "pass", "yield",
-              "break", "except", "import", "print", "class", "exec",
-              "in", "raise", "continue", "finally", "is", "return",
-              "def", "for", "lambda", "try",
-              "None" ) )
-"""The keywords reserved for Python."""
+_PythonKeywords = frozenset( (
+        "and", "as", "assert", "break", "class", "continue", "def", "del",
+        "elif", "else", "except", "exec", "finally", "for", "from", "global",
+        "if", "import", "in", "is", "lambda", "not", "or", "pass", "print",
+        "raise", "return", "try", "while", "with", "yield"
+        ) )
+"""Python keywords.  Note that types like int and float are not
+keywords.
+
+@see: U{http://docs.python.org/reference/lexical_analysis.html#keywords}."""
+
+_PythonBuiltInConstants = frozenset( (
+        "False", "True", "None", "NotImplemented", "Ellipsis", "__debug__",
+        ) )
+"""Other symbols that aren't keywords but that can't be used.
+
+@see: U{http://docs.python.org/library/constants.html}."""
+
+_Keywords = frozenset(_PythonKeywords.union(_PythonBuiltInConstants))
+"""The keywords reserved for Python, derived from L{_PythonKeywords}
+and L{_PythonBuiltInConstants}."""
 
 def DeconflictKeyword (s, aux_keywords=frozenset()):
     """If the provided string C{s} matches a Python language keyword,
@@ -545,17 +567,44 @@ def TextFromURI (uri, archive_directory=None):
 
     If the uri does not include a scheme (e.g., C{http:}), it is
     assumed to be a file path on the local system."""
+    import urllib
     import urllib2
-    xmls = None
+    stream = None
+    exc = None
+    # Only something that has a colon is a non-file URI.  Some things
+    # that have a colon are a file URI (sans schema).  Prefer urllib2,
+    # but allow urllib (which apparently works better on Windows).
+    if 0 <= uri.find(':'):
+        try:
+            stream = urllib2.urlopen(uri)
+        except Exception, e:
+            exc = e
+        if stream is None:
+            try:
+                stream = urllib.urlopen(uri)
+                exc = None
+            except:
+                # Prefer urllib exception
+                pass
+    if stream is None:
+        # No go as URI; give file a chance
+        try:
+            stream = file(uri)
+            exc = None
+        except Exception, e:
+            if exc is None:
+                exc = e
+    if exc is not None:
+        print 'TextFromURI: open %s caught: %s' % (uri, exc)
+        raise exc
     try:
-        if 0 <= uri.find(':'):
-            xmls = urllib2.urlopen(uri).read()
-        else:
-            xmls = file(uri).read()
+        # Protect this in case whatever stream is doesn't have an fp
+        # attribute.
+        if isinstance(stream, file) or isinstance(stream.fp, file):
             archive_directory = None
-    except Exception, e:
-        print 'TextFromURI: open %s caught: %s' % (uri, e)
-        raise
+    except:
+        pass
+    xmls = stream.read()
     if archive_directory:
         base_name = os.path.basename(os.path.normpath(urlparse.urlparse(uri)[2]))
         counter = 1
@@ -598,7 +647,7 @@ def OpenOrCreate (file_name, tag=None, preserve_contents=False):
         except Exception, e:
             if not (isinstance(e, (OSError, IOError)) and (errno.EEXIST == e.errno)):
                 raise
-    fp = file(file_name, 'a+')
+    fp = file(file_name, 'ab+')
     if (tag is not None) and (0 < os.fstat(fp.fileno()).st_size):
         text = fp.read(4096)
         if 0 > text.find(tag):
@@ -628,6 +677,8 @@ def HashForText (text):
 
     @return: A C{str}, generally a sequence of hexadecimal "digit"s.
     """
+    if isinstance(text, unicode):
+        text = text.encode('utf-8')
     return __Hasher(text).hexdigest()
 
 # uuid didn't show up until 2.5
@@ -967,6 +1018,7 @@ def GetMatchingFiles (path, pattern=None, default_path_wildcard=None, default_pa
         if default_path_wildcard == path:
             if default_path is not None:
                 path_set[0:0] = default_path.split(':')
+                default_path = None
             continue
         recursive = False
         if (prefix_pattern is not None) and path.startswith(prefix_pattern):
