@@ -7,12 +7,11 @@ class Test_ID (unittest.TestCase):
         valid = [ 'schema', '_Underscore', '_With.Dot', 'With-Hyphen' ]
         for f in valid:
             self.assertEqual(f, xsd.ID(f))
-        self.assertEqual('LeadingSpace', xsd.ID('  LeadingSpace'))
-        self.assertEqual('TrailingSpace', xsd.ID('TrailingSpace  '))
 
     def testInvalid (self):
         invalid = [ '.DotFirst', 'With Spaces', 'With:Colon', 
-                    'With?Illegal', '??LeadingIllegal', 'TrailingIllegal??']
+                    'With?Illegal', '??LeadingIllegal', 'TrailingIllegal??',
+                    '  LeadingSpace', 'TrailingSpace   ']
         for f in invalid:
             self.assertRaises(BadTypeValueError, xsd.ID, f)
 
