@@ -34,7 +34,7 @@ xsd='''<?xml version="1.0" encoding="UTF-8"?>
 </xs:schema>'''
 
 code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
-file('code.py', 'w').write(code)
+#file('code.py', 'w').write(code)
 #print code
 
 rv = compile(code, 'test', 'exec')
